@@ -68,14 +68,13 @@ SAUF
 gboolean FileIs_vidm4a( gchar *namefile )
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
 	
 	if( (buf = (gchar *)g_malloc0 (sizeof(gchar) * 2048)) == NULL ) return (FALSE);
 	if( (fp = fopen (namefile, "rb")) != NULL ) {
-		lenread = fread( buf, 1, 2000, fp );
+		fread( buf, 1, 2000, fp );
 		fclose (fp);
 	}
 
@@ -105,14 +104,13 @@ gboolean FileIs_vidm4a( gchar *namefile )
 gboolean FileIs_m4a( gchar *namefile )
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
 	
 	if( (buf = (gchar *)g_malloc0 (sizeof(gchar) * 2048)) == NULL ) return (FALSE);
 	if( (fp = fopen (namefile, "rb")) != NULL ) {
-		lenread = fread( buf, 1, 2000, fp );
+		fread( buf, 1, 2000, fp );
 		fclose (fp);
 	}
 
@@ -137,10 +135,9 @@ gboolean FileIs_wavpack (gchar *namefile)
 {
 	FILE      *fp = NULL;
 	gchar      str [ 42 ] = {'\0','\0','\0','\0','\0','\0','\0','\0'};
-	size_t     lenread = 0;
 
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (&str[0], 1, 40, fp);
+		fread (&str[0], 1, 40, fp);
 		fclose (fp);
 	}
 
@@ -176,13 +173,12 @@ gboolean FileIs_wav (gchar *namefile)
 {
 	FILE        *fp = NULL;
 	HEADER_WAV   buf;
-	size_t	 Dummy;
 	
 	if ((fp = fopen (namefile, "r")) == NULL) return (FALSE);
-	Dummy = fread(&buf.tag1, 1, 4, fp);
+	fread(&buf.tag1, 1, 4, fp);
 	buf.tag1 [ 4 ] = '\0';
-	Dummy = fread(&buf.tag2, 1, 4, fp);
-	Dummy = fread(&buf.tag2, 1, 14, fp);
+	fread(&buf.tag2, 1, 4, fp);
+	fread(&buf.tag2, 1, 14, fp);
 	fclose (fp);
 	if ((buf.tag1 [ 0 ] == 'R' &&
 	     buf.tag1 [ 1 ] == 'I' &&
@@ -202,10 +198,9 @@ gboolean FileIs_shn (gchar *namefile)
 {
 	FILE      *fp = NULL;
 	gchar      str [ 8 ] = {'\0','\0','\0','\0','\0','\0','\0','\0'};
-	size_t     lenread = 0;
 
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (&str[0], 1, 4, fp);
+		fread (&str[0], 1, 4, fp);
 		fclose (fp);
 	}
 
@@ -228,7 +223,6 @@ $ file *.rm
 gboolean FileIs_rm (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gboolean     bool_signature = FALSE;
 	
@@ -236,7 +230,7 @@ gboolean FileIs_rm (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 512);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 500, fp);
+		fread (buf, 1, 500, fp);
 		fclose (fp);
 	
 		if (buf [  0 ] == 0x2e &&	// .
@@ -263,14 +257,13 @@ gboolean FileIs_rm (gchar *namefile)
 gboolean FileIs_ogg (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
 	
 	if ((buf = (gchar *)g_malloc0 (sizeof(gchar) * 2048)) == NULL) return (FALSE);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 2000, fp);
+		fread (buf, 1, 2000, fp);
 		fclose (fp);
 	}
 
@@ -309,7 +302,6 @@ gboolean FileIs_ogg (gchar *namefile)
 gboolean FileIs_mpc (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
@@ -318,7 +310,7 @@ gboolean FileIs_mpc (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 1034);
 	if((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 1024, fp);
+		fread (buf, 1, 1024, fp);
 		fclose (fp);
 	}
 	// 
@@ -360,7 +352,6 @@ gboolean FileIs_mpc (gchar *namefile)
 gboolean FileIs_ac3 (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gboolean     BoolSignature = FALSE;
 	
@@ -369,7 +360,7 @@ gboolean FileIs_ac3 (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 100);
 	if((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 50, fp);
+		fread (buf, 1, 50, fp);
 		fclose (fp);
 	}
 	
@@ -404,17 +395,16 @@ gboolean FileIs_mp3 (gchar *namefile)
 	gboolean bool_signature = FALSE;
 	gint     i;
 	size_t   size;
-	glong	 Dummy;
 
 	// PRINT_FUNC_LF();
 
 	fp = fopen (namefile, "rb");
 	if (NULL == fp) return (FALSE);
 
-	Dummy = fread ( &begin, 128, 1, fp );
+	fread ( &begin, 128, 1, fp );
 	fseek ( fp, 0, SEEK_END );
 	fseek ( fp, ftell( fp ) - 128, SEEK_SET );
-	Dummy = fread ( &end, 128, 1, fp );
+	fread ( &end, 128, 1, fp );
 	fclose (fp);
 	
 	// TEST SI FICHIER EST: AC3
@@ -433,7 +423,7 @@ gboolean FileIs_mp3 (gchar *namefile)
 	size = libutils_get_size_file (namefile);
 	buf = g_malloc0 (sizeof (gchar) * (size + 10));
 	if ((fp = fopen (namefile, "rb"))) {
-		Dummy = fread (buf, 1, size, fp);
+		fread (buf, 1, size, fp);
 		fclose (fp);
 		for (i = 0; i < size; i ++) {
 			if (buf[i+0] == 'L' && buf[i+1] == 'A' && buf[i+2] == 'M' && buf[i+3] == 'E') {
@@ -489,7 +479,6 @@ gboolean FileIs_mp3 (gchar *namefile)
 gboolean FileIs_flac (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
@@ -498,7 +487,7 @@ gboolean FileIs_flac (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5124);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 5120, fp);
+		fread (buf, 1, 5120, fp);
 		fclose (fp);
 	}
 	
@@ -552,7 +541,6 @@ struct APE_HEADER_OLD
 gboolean FileIs_ape (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
@@ -561,7 +549,7 @@ gboolean FileIs_ape (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5120);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 5000, fp);
+		fread (buf, 1, 5000, fp);
 		fclose (fp);
 	
 		for (cpt = 0; cpt < 5000; cpt ++) {
@@ -603,7 +591,6 @@ POS	ASCII	HEXA
 gboolean FileIs_aiff (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gboolean     bool_signature = FALSE;
 	
@@ -611,7 +598,7 @@ gboolean FileIs_aiff (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 512);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 500, fp);
+		fread (buf, 1, 500, fp);
 		fclose (fp);
 	
 		if (buf [  0 ] == 0x46 &&	// F
@@ -709,7 +696,6 @@ gboolean FileIs_g_str_has_suffix (gchar *NameSong, gchar *Suffixe)
 gboolean FileIs_png (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
@@ -718,7 +704,7 @@ gboolean FileIs_png (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5124);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 5120, fp);
+		fread (buf, 1, 5120, fp);
 		fclose (fp);
 	}
 	
@@ -742,7 +728,6 @@ gboolean FileIs_png (gchar *namefile)
 gboolean FileIs_jpg (gchar *namefile)
 {
 	FILE        *fp = NULL;
-	size_t       lenread = 0;
 	gchar       *buf = NULL;
 	gint         cpt;
 	gboolean     bool_signature = FALSE;
@@ -751,7 +736,7 @@ gboolean FileIs_jpg (gchar *namefile)
 
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5124);
 	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 5120, fp);
+		fread (buf, 1, 5120, fp);
 		fclose (fp);
 	}
 	
