@@ -57,7 +57,8 @@
 OPTIONS_COMMAND_LINE OptionsCommandLine = {
 	FALSE,		// gboolean	BoolVerboseMode
 	FALSE,		// gboolean	BoolVersionMode
-	FALSE		// gboolean	BoolHelpMode
+	FALSE,		// gboolean	BoolHelpMode
+	FALSE		// gboolean	BoolSystray
 };
 
 
