@@ -38,11 +38,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 
 #include <errno.h>
@@ -207,7 +202,8 @@ gboolean AlsaAudio_open_device(
 	}
 	else {
 		PRINT_FUNC_LF();
-		g_print("Format de bitrate [ %d ] non prit en charge\n", p_bitsPerSample);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print("Format de bitrate [ %d ] non prit en charge\n", p_bitsPerSample);
 		return (FALSE);	
 	}
 	
@@ -218,19 +214,22 @@ gboolean AlsaAudio_open_device(
 	/* setup dsp device */
 	err = snd_pcm_open(&VarAlsa.playback_handle, audio_dev, SND_PCM_STREAM_PLAYBACK, 0);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot open audio device %s (%s)\n", audio_dev, snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot open audio device %s (%s)\n", audio_dev, snd_strerror(err));
 		return (FALSE);
 	}
  
 	err = snd_pcm_hw_params_malloc(&hw_params);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot allocate hardware parameter structure (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot allocate hardware parameter structure (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
 	err = snd_pcm_hw_params_any(VarAlsa.playback_handle, hw_params);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot initialize hardware parameter structure (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot initialize hardware parameter structure (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
@@ -243,7 +242,8 @@ gboolean AlsaAudio_open_device(
 	/* set format */
 	err = snd_pcm_hw_params_set_format(VarAlsa.playback_handle, hw_params, format);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot set sample format (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot set sample format (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
@@ -251,47 +251,54 @@ gboolean AlsaAudio_open_device(
 	rrate = rate;
 	err = snd_pcm_hw_params_set_rate_near(VarAlsa.playback_handle, hw_params, &rrate, 0);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot set sample rate (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot set sample rate (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
 	/* set channels */
 	err = snd_pcm_hw_params_set_channels(VarAlsa.playback_handle, hw_params, VarAlsa.channels);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot set channel count (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot set channel count (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
 	/* set the buffer time */
 	err = snd_pcm_hw_params_set_buffer_time_near(VarAlsa.playback_handle, hw_params, &buffer_time, &dir);
 	if (err < 0 ) {
-		printf("Unable to set buffer time %i for playback: %s\n", buffer_time, snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			printf("Unable to set buffer time %i for playback: %s\n", buffer_time, snd_strerror(err));
 		return (FALSE);
 	}
 
 	/* set the period time */
 	err = snd_pcm_hw_params_set_period_time_near(VarAlsa.playback_handle, hw_params, &period_time, &dir);
 	if (err < 0 ) {
-		printf("Unable to set period time %i for playback: %s\n", period_time, snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			printf("Unable to set period time %i for playback: %s\n", period_time, snd_strerror(err));
 		return (FALSE);
 	}
 
 	/* commit parameters */
 	err = snd_pcm_hw_params(VarAlsa.playback_handle, hw_params);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot set parameters (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot set parameters (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
 	err = snd_pcm_hw_params_get_buffer_size(hw_params, &buffer_size);
 	if (err < 0 ) {
-		printf("Unable to get buffer size for playback: %s\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			printf("Unable to get buffer size for playback: %s\n", snd_strerror(err));
 		return (FALSE);
 	}
 
 	err = snd_pcm_hw_params_get_period_size(hw_params, &period_size, 0);
 	if (err < 0 ) {
-		printf("Unable to get period size for playback: %s\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			printf("Unable to get period size for playback: %s\n", snd_strerror(err));
 		return (FALSE);
 	}
 	*p_bufferSize = snd_pcm_frames_to_bytes(VarAlsa.playback_handle, period_size);
@@ -300,7 +307,8 @@ gboolean AlsaAudio_open_device(
 
 	err = snd_pcm_prepare(VarAlsa.playback_handle);
 	if (err < 0 ) {
-		fprintf(stderr, "cannot prepare audio interface for use (%s)\n", snd_strerror(err));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			fprintf(stderr, "cannot prepare audio interface for use (%s)\n", snd_strerror(err));
 		return (FALSE);
 	}
 
