@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
@@ -89,7 +84,7 @@ static void AlsaPlay_thread (void *arg)
 	AlsaPlay_TRet = 0.0;
 	
 	while ((Ret = fread (VarAlsa.buffer,  1, VarAlsa.SizeBuffer, VarAlsa.pFile)) > 0) {
-		
+				
 		if (VarAlsa.StopPlay == TRUE) break;
 				
 		AlsaPlay_TRet +=  Ret;
