@@ -45,11 +45,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -118,6 +113,8 @@ typedef struct {
 	gint		 NbrList;
 	gchar		*PtrDirActuel;
 	
+	gchar		*PathDestinationModeExpert;
+	
 } VAR_CDEXTRACT;
 
 VAR_CDEXTRACT VarCdExtract;
@@ -342,7 +339,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.num_track             = NULL;
 				param_filelc.BoolSetBitrate        = FALSE;
 				param_filelc.PtrStrBitrate         = NULL;
-				param_filelc.PtrStrBitrate         = options_get_params (OGGENC_WAV_TO_OGG, NULL);
+				param_filelc.PtrStrBitrate         = options_get_params (OGGENC_WAV_TO_OGG);
 
 				Audio->ListConv[ NUM_OGG ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				filelc_get_command_line (&param_filelc);
@@ -373,7 +370,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.num_track             = NULL;
 				param_filelc.BoolSetBitrate        = FALSE;
 				param_filelc.PtrStrBitrate         = NULL;
-				param_filelc.PtrStrBitrate         = options_get_params (AACPLUSENC_WAV_TO_AAC, NULL);
+				param_filelc.PtrStrBitrate         = options_get_params (AACPLUSENC_WAV_TO_AAC);
 
 				Audio->ListConv[ NUM_AAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				filelc_get_command_line (&param_filelc);
@@ -411,7 +408,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.num_track             = NULL;
 				param_filelc.BoolSetBitrate        = FALSE;
 				param_filelc.PtrStrBitrate         = NULL;
-				param_filelc.PtrStrBitrate         = options_get_params (LAME_WAV_TO_MP3, NULL);
+				param_filelc.PtrStrBitrate         = options_get_params (LAME_WAV_TO_MP3);
 
 				Audio->ListConv[ NUM_MP3 ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				filelc_get_command_line (&param_filelc);
@@ -483,10 +480,18 @@ gboolean cdaudioextract_create_list_is_Extract (void)
 				*/
 				switch (Config.ExtractCdWith) {
 				case EXTRACT_WITH_CDPARANOIA :
-					param_filelc.type_conv             = CDPARANOIA_CD_TO_WAV;
+				case EXTRACT_WITH_CDPARANOIA_MODE_2 :
+					// 
+					// SUITE MAIL DE: Levis Florian:
+					// TEST EXTRACTION AVEC CDPARANOIA EN MODE EXPERT UNE SEULE PASSE ...
+					// 
+					if( EXTRACT_WITH_CDPARANOIA == Config.ExtractCdWith )
+						param_filelc.type_conv             = CDPARANOIA_CD_TO_WAV;
+					else	param_filelc.type_conv             = CDPARANOIA_CD_TO_WAV_EXPERT;
 					param_filelc.With_CommandLineUser  = FALSE;
 					param_filelc.filesrc               = Audio->PathName_Dest_Wav;
-					param_filelc.filedest              = Audio->PathName_Dest_Wav;
+					// param_filelc.filedest              = Audio->PathName_Dest_Wav;
+					param_filelc.filedest              = Audio->PathName_Dest_Tmp;
 					param_filelc.tags                  = NULL;
 					param_filelc.cdrom                 = EnteteCD.NameCD_Device;
 					param_filelc.num_track             = Audio->Str_Track;
@@ -494,6 +499,7 @@ gboolean cdaudioextract_create_list_is_Extract (void)
 					Audio->ListConv[ NUM_WAV ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 					filelc_get_command_line_extract (&param_filelc);
 					cdaudioextract_save_arg_from_extract (Audio, NUM_WAV);
+					
 					break;
 				case EXTRACT_WITH_CDPARANOIA_EXPERT :
 					
@@ -604,7 +610,6 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2
 	gchar		*Ptr2 = NULL;
 	gchar		 Buf1 [ 2500 ];
 	gchar		 Buf2 [ 2500 ];
-	size_t		 LenFread = 0;
 	gint		 Elem;
 	gint		 Cpt;
 	gint		 TotalElem = LenFile;
@@ -621,8 +626,8 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2
 	fp3 = fopen (PathNameDest, "w");
 	
 	// Lecture des entetes
-	LenFread = fread (Buf1, 1, 44, fp1);
-	LenFread = fread (Buf2, 1, 44, fp2);
+	fread (Buf1, 1, 44, fp1);
+	fread (Buf2, 1, 44, fp2);
 	// Ecriture de l entete du fichier de destination
 	fwrite (Buf1, sizeof(gchar), 44, fp3);
 	
@@ -634,8 +639,8 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2
 		memset (Buf2, '\0', 2498);
 		
 		// Lectures des segments
-		LenFread = fread (Buf1, 1, 2352, fp1);
-		LenFread = fread (Buf2, 1, 2352, fp2);
+		fread (Buf1, 1, 2352, fp1);
+		fread (Buf2, 1, 2352, fp2);
 		
 		/* -------------------------------------------------------------
 		*  DEBUG - DEBUG - DEBUG - DEBUG - DEBUG - DEBUG - DEBUG - DEBUG
@@ -696,18 +701,18 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2
 
 			// Lecture segment 'Elem' pour Buf1
 			fpElem = fopen (Name1, "r");
-			LenFread = fread (Buf1, 1, 44, fpElem);
+			fread (Buf1, 1, 44, fpElem);
 			memset (Buf1, '\0', 2498);
-			LenFread = fread (Buf1, 1, 2352, fpElem);
+			fread (Buf1, 1, 2352, fpElem);
 			fclose (fpElem);
 			g_free (Name1);
 			Name1 = NULL;
 			
 			// Lecture segment 'Elem' pour Buf2
 			fpElem = fopen (Name2, "r");
-			LenFread = fread (Buf2, 1, 44, fpElem);
+			fread (Buf2, 1, 44, fpElem);
 			memset (Buf2, '\0', 2498);
-			LenFread = fread (Buf2, 1, 2352, fpElem);
+			fread (Buf2, 1, 2352, fpElem);
 			fclose (fpElem);			
 			g_free (Name2);
 			Name2 = NULL;
@@ -734,8 +739,6 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 	
 	PRINT("DEBUT THREAD EXTRACTION");
 	
-	// logs_add_datas_session ("FROM CD");
-		
 	ListOne = g_list_first (EnteteCD.GList_Audio_cd);
 	while (FALSE == conv.bool_stop && NULL != ListOne) {
 
@@ -751,12 +754,15 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				
 				switch (Config.ExtractCdWith) {
 				case EXTRACT_WITH_CDPARANOIA :
+				case EXTRACT_WITH_CDPARANOIA_MODE_2 :
 					if (FALSE == conv.bool_stop) {
 					
-						// logs_writeln_datas ("EXTRACT_WITH_CDPARANOIA: ");
-						
 						cdaudioextract_restitue_arg_to_extract (Audio, NUM_WAV);
 						conv_exec_extract (Audio->ListConv[ NUM_WAV ].WithCommandLineUser, CDPARANOIA_CD_TO_WAV, "CDPARANOIA_CD_TO_WAV");
+						
+						conv_copy_src_to_dest( Audio->PathName_Dest_Tmp, Audio->PathName_Dest_Wav );
+						g_unlink( Audio->PathName_Dest_Tmp );
+						
 					}
 					break;
 				case EXTRACT_WITH_CDPARANOIA_EXPERT :
@@ -764,8 +770,6 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 						
 						gchar *Str = NULL;
 						
-						// logs_writeln_datas ("EXTRACT_WITH_CDPARANOIA_EXPERT: ");
-						
 						Str = g_strdup_printf (_("\n[Piste: %d]\n"), Audio->Num_Track);
 						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
@@ -804,13 +808,9 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				case EXTRACT_WITH_CDDA2WAV :
 
 					if (FALSE == conv.bool_stop) {
-						/*g_chdir (conv.TmpRep);*/
-							
-						// logs_writeln_datas ("EXTRACT_WITH_ICEDAX: ");
 							
 						cdaudioextract_restitue_arg_to_extract (Audio, NUM_WAV);
 						conv_exec_extract (Audio->ListConv[ NUM_WAV ].WithCommandLineUser, CDDA2WAV_CD_TO_WAV, "CDDA2WAV_CD_TO_WAV");
-						/*g_chdir (VarCdExtract.PtrDirActuel);*/
 						
 						if (FALSE == conv.bool_stop) {
 							
@@ -832,19 +832,15 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				if (FALSE == conv.bool_stop && TRUE == Audio->EtatNormalise) {
 					switch (VarCdExtract.ComboNumActive) {
 					case 0 :
-						// logs_writeln_datas ("\tNORMALISATION PEAK/ALBUM");
 						Audio->EtatPeak = CD_NORM_PEAK_WAITING;
 						PRINT("ADD PEAK/ALBUM");
 						CdNormalise_add_PeakGroup ();
 						break;
 					case 1 :
-						// logs_writeln_datas ("\tNORMALISATION PEAK");
 						Audio->EtatPeak = CD_NORM_PEAK_WAITING;
 						break;
 					}
 				}
-				// logs_write_datas ("\t");
-				// logs_writeln_datas (Audio->PathName_Dest_Wav);
 				
 				Audio->EtatSelection_Wav = CD_ETAT_ATTENTE;
 
@@ -873,7 +869,6 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 	if (FALSE == conv.bool_stop && TRUE == VarCdExtract.BoolListIsPeakAlbum) {
 	
 		PRINT("DEBUT NORMALISATION PEAK/ALBUM");
-		// logs_write_datas ("\tNORMALISATION PEAK/ALBUM with ");
 			
 		if (FALSE == conv.bool_stop &&
 			  CdNormalise_get_is_list_PeakGroup () == TRUE &&
@@ -913,9 +908,6 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			conv_to_convert (FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL -> PEAK/GROUP");
 			filelc_get_command_line_remove ();
 			
-			// logs_write_double (conv.value_PEAK_RMS_GROUP_ARGS);
-			// logs_writeln_datas ("dB");
-			
 			// -- APPLIQUER LA MOYENNE PEAK
 			if (FALSE == conv.bool_stop) {
 				pos = filelc_get_command_line_nice ();
@@ -927,8 +919,6 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
 				while (List2) {
 					if (NULL != (VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data)) {
-						// logs_write_datas ("\t");
-						// logs_writeln_datas (VarCDNormaliseElement->PathNameDest);
 						conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc);
 					}
 					List2 = g_list_next(List2);
@@ -1085,9 +1075,10 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				
 				conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
 				filelc_get_command_line_remove ();
-	PRINT("DEBUG FOR @DZEF");
-if( TRUE == OptionsCommandLine.BoolVerboseMode )
-	g_print("\t%s = %s\n\n", VarCdExtract.NameFileFormatUnique, libutils_test_file_exist (VarCdExtract.NameFileFormatUnique) ? "EXIST" : "NOT FOUND");
+				
+				PRINT("DEBUG FOR @DZEF");
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print("\t%s = %s\n\n", VarCdExtract.NameFileFormatUnique, libutils_test_file_exist (VarCdExtract.NameFileFormatUnique) ? "EXIST" : "NOT FOUND");
 	
 				conv.Bool_MAJ_select = TRUE;
 			}
@@ -1107,11 +1098,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("DEST   FLAC<%s>\n", Audio->PathName_Dest_Flac);
 			}
 			
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_Flac);
-
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_FLAC);
 			conv_to_convert (Audio->ListConv[ NUM_FLAC ].WithCommandLineUser,  FLAC_WAV_TO_FLAC, "FLAC_WAV_TO_FLAC");
 			filelc_get_command_line_remove ();
@@ -1134,10 +1120,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 				g_print ("DEST   APE <%s>\n", Audio->PathName_Dest_Ape);
 			}
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_Ape);
 
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_APE);
 			conv_to_convert (Audio->ListConv[ NUM_APE ].WithCommandLineUser,  MAC_WAV_TO_APE, "MAC_WAV_TO_APE");
@@ -1165,11 +1147,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("DEST   WAVPACK <%s>\n", Audio->PathName_Dest_WavPack);
 			}
 			
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_WavPack);
-
 			Audio->EtatBoolWavpack = TRUE;
 			
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_WAVPACK);
@@ -1209,10 +1186,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 				g_print ("DEST   OGG <%s>\n", Audio->PathName_Dest_Ogg);
 			}
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_Ogg);
 
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_OGG);
 			conv_to_convert (Audio->ListConv[ NUM_OGG ].WithCommandLineUser, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
@@ -1236,10 +1209,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 				g_print ("DEST   M4A <%s>\n", Audio->PathName_Dest_M4a);
 			}
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_M4a);
 
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_M4A);
 			conv_to_convert (Audio->ListConv[ NUM_M4A ].WithCommandLineUser, FAAC_WAV_TO_M4A, "FAAC_WAV_TO_M4A");
@@ -1263,10 +1232,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 				g_print ("DEST   AAC <%s>\n", Audio->PathName_Dest_Aac);
 			}
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_Aac);
 
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_AAC);
 			conv_to_convert (Audio->ListConv[ NUM_AAC ].WithCommandLineUser, AACPLUSENC_WAV_TO_AAC, "AACPLUSENC_WAV_TO_AAC");
@@ -1292,10 +1257,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 				g_print ("DEST   MPC <%s>\n", Audio->PathName_Dest_Mpc);
 			}
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_Mpc);
 
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_MPC);
 			conv_to_convert (Audio->ListConv[ NUM_MPC ].WithCommandLineUser, MPPENC_WAV_TO_MPC, "MPPENC_WAV_TO_MPC");
@@ -1319,10 +1280,6 @@ if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 				g_print ("DEST   MP3 <%s>\n", Audio->PathName_Dest_Mp3);
 			}
-			// logs_write_datas ("\t");
-			// logs_write_datas (Audio->PathName_Dest_Wav);
-			// logs_write_datas (" -> ");
-			// logs_writeln_datas (Audio->PathName_Dest_Mp3);
 
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_MP3);
 			conv_to_convert (Audio->ListConv[ NUM_MP3 ].WithCommandLineUser, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
@@ -1379,17 +1336,39 @@ static gint cdaudioextract_timeout (gpointer data)
 
 		GList		*List = NULL;
 		gchar		*Ptr = NULL;
+		FILE		*fp = NULL;
 		
 	 	if (NULL != (List = g_list_first (conv.ListPutTextview))) {
+	 		
+	 		if( TRUE == OptionsCd_get_save_log_mode_expert()) {
+	 			
+	 			gchar	*StrModeExpert = NULL;
+	 			
+	 			StrModeExpert = g_strdup_printf( "%s/LogExpertMode.txt", VarCdExtract.PathDestinationModeExpert );
+	 			fp = fopen( StrModeExpert, "a" );
+	 			g_free( StrModeExpert );
+	 			StrModeExpert = NULL;
+	 		}
+			
 			while (List) {
 				if (NULL != (Ptr = (gchar *)List->data)) {
 					WinVte_window_write_va( Ptr, NULL );
+					
+					// SAVE LOG FROM CDPARANOIA MODE EXPERT
+					if( TRUE == OptionsCd_get_save_log_mode_expert()) {
+						fprintf( fp, "%s", Ptr );
+					}
+					
 					g_free (Ptr);
 					Ptr = NULL;
 					List->data = NULL;
 				}
 				List = g_list_next(List);
 			}
+	 		
+	 		if( TRUE == OptionsCd_get_save_log_mode_expert())
+				fclose( fp );
+			
 			conv.BoolPutTextview = FALSE;
 		}
 	}
@@ -1468,7 +1447,7 @@ static gint cdaudioextract_timeout (gpointer data)
 
 							if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK)	fprintf (fp, "%s\n", Audio->PathName_Dest_Flac);
 							if (Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
-							    Audio->BoolM3uForWav == TRUE)	fprintf (fp, "%s\n", Audio->PathName_Dest_Wav);
+							    Audio->BoolM3uForWav == TRUE)			fprintf (fp, "%s\n", Audio->PathName_Dest_Wav);
 							if (Audio->Etat_Mp3 == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Mp3);
 							if (Audio->Etat_Ogg == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Ogg);
 							if (Audio->Etat_m4a == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_M4a);
@@ -1505,9 +1484,10 @@ static gint cdaudioextract_timeout (gpointer data)
 						    Audio->Etat_Ape == ETAT_CONV_CD_CONV_OK ||
 						    Audio->Etat_WavPack == ETAT_CONV_CD_CONV_OK) {
 							
-							if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK)	fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Flac);
+							if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK)
+														fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Flac);
 							if (Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK && Audio->BoolM3uForWav == TRUE)
-												fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Wav);
+														fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Wav);
 							if (Audio->Etat_Mp3 == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Mp3);
 							if (Audio->Etat_Ogg == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Ogg);
 							if (Audio->Etat_m4a == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_M4a);
@@ -1557,7 +1537,7 @@ static gint cdaudioextract_timeout (gpointer data)
 					g_free (Audio->PathName_Dest_Wav);
 					Audio->PathName_Dest_Wav = NULL;
 				}
-
+				
 				if (Audio->PathName_Dest_Mp3) {
 					if (Audio->Bool_Delette_Mp3) {
 						if( TRUE == OptionsCommandLine.BoolVerboseMode )
@@ -1627,6 +1607,12 @@ static gint cdaudioextract_timeout (gpointer data)
 					g_free (Audio->PathName_Dest_WavPack);
 					Audio->PathName_Dest_WavPack = NULL;
 				}
+				
+				if( Audio->PathName_Dest_Tmp ) {
+					g_free( Audio->PathName_Dest_Tmp );
+					Audio->PathName_Dest_Tmp = NULL;
+				}
+				
 				if (Audio->ExtractExpert.Name1) {
 					g_free (Audio->ExtractExpert.Name1);
 					Audio->ExtractExpert.Name1 = NULL;
@@ -1777,6 +1763,9 @@ void cdaudioextract_set_flags_before_extraction (void)
 				if (Config.ExtractCdWith == EXTRACT_WITH_CDPARANOIA_EXPERT) {
 					conv.total_rip ++;	// PASS 2
 				}
+				if( Config.ExtractCdWith == EXTRACT_WITH_CDPARANOIA || Config.ExtractCdWith == EXTRACT_WITH_CDPARANOIA_MODE_2 ) {
+					conv.total_rip ++;	// NORMAL PASS
+				}
 				conv.total_rip ++;		// NORMAL PASS
 				cdcue_set_BoolExtract (IndexExtraction, TRUE);
 			}
@@ -1818,16 +1807,25 @@ void cdaudioextract_set_flags_before_extraction (void)
 			if (NULL == PathDest) {
 				PathDest = cdaudio_get_result_destination ();
 				g_mkdir_with_parents (PathDest, 0700);
+				
+				if( NULL != VarCdExtract.PathDestinationModeExpert ) {
+					g_free( VarCdExtract.PathDestinationModeExpert );
+					VarCdExtract.PathDestinationModeExpert = NULL;
+				}
+				VarCdExtract.PathDestinationModeExpert = g_strdup( PathDest );
 			}
 			// Create tmp rep
-			if (NULL == conv.TmpRep)  {
+			if( NULL == conv.TmpRep )
 				conv.TmpRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_AUDIOCD);
-			}
+			
+			if( NULL == Audio->PathName_Dest_Tmp )
+				Audio->PathName_Dest_Tmp = g_strdup_printf( "%s/TempAudioExtract_%02d.wav", conv.TmpRep, IndexExtraction +1 );
 		
 			if (Audio->Etat_Wav == ETAT_CONV_CD_WAITING) {
 
 				switch (Config.ExtractCdWith) {
 				case EXTRACT_WITH_CDPARANOIA :
+				case EXTRACT_WITH_CDPARANOIA_MODE_2 :
 					if (Audio->EtatSelection_Wav <= CD_ETAT_ATTENTE_EXIST) {
 
 						Audio->PathName_Dest_Wav = g_strdup_printf ("%s/%s.wav", conv.TmpRep, Audio->NameSong);
@@ -1935,6 +1933,7 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 		Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
 		if (*Ptr == '\0') {
 			wininfo_create (
+				WindMain,
 				_("Nom de fichier unique absent"),
 				_("Veuillez saisir un nom pour le fichier unique"),
 				  "");
@@ -1944,6 +1943,8 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 
 	if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_extract_with_cdparanoia)) == TRUE)
 		Config.ExtractCdWith = EXTRACT_WITH_CDPARANOIA;
+	else if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_2)) == TRUE)
+		Config.ExtractCdWith = EXTRACT_WITH_CDPARANOIA_MODE_2;
 	else if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_expert)) == TRUE)
 		Config.ExtractCdWith = EXTRACT_WITH_CDPARANOIA_EXPERT;
 	else if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_extract_with_cdda2wav)) == TRUE)
@@ -1984,7 +1985,7 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 
 	VarCdExtract.PtrDirActuel = g_get_current_dir ();
 	g_chdir (conv.TmpRep);
-
+	
 	PopupSystray_set_BoolMainAction (TRUE);
 	
 	conv.bool_thread_conv = TRUE;
