@@ -103,16 +103,28 @@ void cdcue_remove_base_ioctl (void)
 	}
 	
 	// g_free (BaseIoctl.PathNameDestFileCue);	BaseIoctl.PathNameDestFileCue = NULL;
-	g_free (BaseIoctl.Performer);		BaseIoctl.Performer = NULL;
-	g_free (BaseIoctl.Title);		BaseIoctl.Title = NULL;
-	g_free (BaseIoctl.File);		BaseIoctl.File = NULL;
+	if( NULL != BaseIoctl.Performer ) {
+		g_free (BaseIoctl.Performer);		BaseIoctl.Performer = NULL;
+	}
+	if( NULL != BaseIoctl.Title ) {
+		g_free (BaseIoctl.Title);		BaseIoctl.Title = NULL;
+	}
+	if( NULL != BaseIoctl.File ) {
+		g_free (BaseIoctl.File);		BaseIoctl.File = NULL;
+	}
 	
 	if (BaseIoctl.Cue != NULL) {
 		gint i;
 		for (i = 0; i < BaseIoctl.TotalTracks; i++) {
-			g_free (BaseIoctl.Cue [ i ].Performer);		BaseIoctl.Cue [ i ].Performer = NULL;
-			g_free (BaseIoctl.Cue [ i ].Title);		BaseIoctl.Cue [ i ].Title = NULL;
-			g_free (BaseIoctl.Cue [ i ].Partiel_Title);	BaseIoctl.Cue [ i ].Partiel_Title = NULL;
+			if( NULL != BaseIoctl.Cue [ i ].Performer ) {
+				g_free (BaseIoctl.Cue [ i ].Performer);		BaseIoctl.Cue [ i ].Performer = NULL;
+			}
+			if( NULL != BaseIoctl.Cue [ i ].Title ) {
+				g_free (BaseIoctl.Cue [ i ].Title);		BaseIoctl.Cue [ i ].Title = NULL;
+			}
+			if( NULL != BaseIoctl.Cue [ i ].Partiel_Title ) {
+				g_free (BaseIoctl.Cue [ i ].Partiel_Title);	BaseIoctl.Cue [ i ].Partiel_Title = NULL;
+			}
 		}
 		g_free (BaseIoctl.Cue);
 		BaseIoctl.Cue = NULL;
