@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -62,9 +57,10 @@
 
 
 /*
-	ABANDON DES LIBRAIRIES
+	-> ABANDON DES LIBRAIRIES
 		CDDB et CDIO
-	AU PROFIT DE:
+	
+	-> AU PROFIT DE:
 	
 	-- Utilisation de:
 	
@@ -339,8 +335,12 @@ void CdCurl_set_list_discid( void )
 		if( NbrOptions > 1 )
 			gtk_widget_show( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
 		else	gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
-		if( TRUE == OptionsCommandLine.BoolVerboseMode )
-			g_print( "NbrOptions = %d [ %s ]\n", NbrOptions,  NbrOptions > 1 ? "gtk_widget_show" : "gtk_widget_hide" );
+		
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print( "CdCurl_set_list_discid()\n" );
+			g_print( "\tNbrOptions = %d [ %s ]\n", NbrOptions,  NbrOptions > 1 ? "gtk_widget_show" : "gtk_widget_hide" );
+		}
+		
 		return;
 	}
 	gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
@@ -433,19 +433,22 @@ gchar *CdCurl_get_str_discid( void )
 //
 void CdCurl_print_glist( void )
 {
-	GList		*List = NULL;
-	VAR_LIST_POPUP	*PtrVarList = NULL;
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		
+		GList		*List = NULL;
+		VAR_LIST_POPUP	*PtrVarList = NULL;
 	
-	PRINT_FUNC_LF();
-	if( FALSE == OptionsCommandLine.BoolVerboseMode ) return;
-	List = g_list_first( VarSector.ListDiscId );
-	while( List ) {
-		if( NULL != ( PtrVarList = (VAR_LIST_POPUP *)List->data )) {
-			g_print( "%10x", PtrVarList->NumCdDiscId );
-			g_print( "\t%s", PtrVarList->StrCdDiscId );
-			g_print( "\t%s\n", PtrVarList->NameGenre );
+		PRINT_FUNC_LF();
+
+		List = g_list_first( VarSector.ListDiscId );
+		while( List ) {
+			if( NULL != ( PtrVarList = (VAR_LIST_POPUP *)List->data )) {
+				g_print( "%10x", PtrVarList->NumCdDiscId );
+				g_print( "\t%s", PtrVarList->StrCdDiscId );
+				g_print( "\t%s\n", PtrVarList->NameGenre );
+			}
+			List = g_list_next( List );
 		}
-		List = g_list_next( List );
 	}
 }
 //
@@ -480,7 +483,7 @@ VAR_LIST_POPUP *CdCurl_alloc_list( gchar *p_str_discid, gchar *p_name_genre  )
 GString *CdCurl_make_line_request_for_query( gchar *p_StrDiscID, gchar *p_GStrCdDiscID )
 {
 	GString	*Gstr = g_string_new( NULL );
-	g_string_sprintfa(
+	g_string_append_printf(
 			Gstr,
 			// http://freedb.org/~cddb/cddb.cgi?cmd=cddb+query+6f11b918+24+150+20835+32512+47955+62530+74420+89332+100575+113692+126522+133245+145330+159460+170647+186450+199462+219450+233727+247745+262270+276072+288807+310705+325995+4539&hello=private+free.the.cddb+xcfa+4.0.4~beta7&proto=6
 			"http://freedb.org/~cddb/cddb.cgi?cmd=cddb+query+%s+%s&hello=private+free.the.cddb+%s+%s&proto=6",
@@ -496,7 +499,7 @@ GString *CdCurl_make_line_request_for_query( gchar *p_StrDiscID, gchar *p_GStrCd
 GString *CdCurl_make_line_request_for_read( gchar *p_MusicType, gchar *p_StrDiscID )
 {
 	GString	*Gstr = g_string_new( NULL );
-	g_string_sprintfa(
+	g_string_append_printf(
 			Gstr,
 			// "http://freedb.org/~cddb/cddb.cgi?cmd=cddb+read+jazz+6f11b918&hello=private+free.the.cddb+xcfa+4.0.4~beta7&proto=6",
 			"http://freedb.org/~cddb/cddb.cgi?cmd=cddb+read+%s+%s&hello=private+free.the.cddb+%s+%s&proto=6",
@@ -685,6 +688,18 @@ void CdCurl_set_datas_buffer( GString *gstr_buffer_title,
 }
 //
 //
+gint CdCurl_get_numtrack_next( gchar *StrTitle )
+{
+	if( ! strncasecmp( StrTitle, "TTITLE", 6 )) {
+		
+		StrTitle += 6;
+		return( atoi( StrTitle ));
+	}
+	
+	return( -1 );
+}
+// 
+//
 void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 {
 	GString		*Gstr = NULL;
@@ -696,6 +711,7 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 	GString 	*gstr_buffer_title             = g_string_new (NULL);
 	GString 	*gstr_buffer_title_time        = g_string_new (NULL);
 	GString 	*gstr_buffer_artist_title_time = g_string_new (NULL);
+	gchar	*PtrNameTrack = NULL;
 	
 	EnteteCD.StrDureeCd  = g_strdup_printf( "%02d:%02d", 
 			BaseIoctl.Datas[ BaseIoctl.TotalTracks ].begin_min,
@@ -794,15 +810,31 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 		
 		return;
 	}
-	
+
 	Larrbuf = g_strsplit( DatasBuffer, "\n", 0 );
 	if( TRUE == OptionsCommandLine.BoolVerboseMode )
 		g_print( "\nREAD\n" );
 	
+	// SUPPRESSION DES CARACTERES INDELICATS
 	for( Cpt = 0; Larrbuf[ Cpt ]; Cpt ++ ) {
 		
+		if( ! strncasecmp( Larrbuf[ Cpt ], "TTITLE", 6 )) {
+			// 
+			// BUG FIND BY @TICROB: SOLVED
+			// DEL CAR '/' IN STRING
+			//
+			for( PtrNameTrack = Larrbuf[ Cpt ]; *PtrNameTrack; PtrNameTrack ++ ) {
+				if( *PtrNameTrack == '/' ) *PtrNameTrack = '-';
+				if( *PtrNameTrack == '\n' ) *PtrNameTrack = '\0';
+				if( *PtrNameTrack == '\r' ) *PtrNameTrack = '\0';
+			}
+		}
+	}
+	
+	for( Cpt = 0; Larrbuf[ Cpt ]; Cpt ++ ) {
+				
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
-			g_print( "%s\n", Larrbuf[ Cpt ] );
+			g_print( "%02d  %s\n", Cpt, Larrbuf[ Cpt ] );
 		
 		if( ! strncasecmp( Larrbuf[ Cpt ], "DTITLE", 6 )) {
 
@@ -839,15 +871,44 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 		}
 		else if( ! strncasecmp( Larrbuf[ Cpt ], "TTITLE", 6 ) && Track < VarSector.TotalTracks ) {
 						
-			gchar	*PtrNameTrack = NULL;
+			gint	NumTrack;
+			GString	*gstr = g_string_new (NULL);
+			
 			
 			// TTITLE0=My Way
 			// TTITLE1=Strangers In The Night
 			// TTITLE2=Theme From New York New York
 			// TTITLE3=I Get A Kick Out Of You
-
+			
+			// 
+			// UNE LIGNE PEUT ETRE SCINDEE SUR PLUSIEURS LIGNES:
+			// -------------------------------------------------
+			// TTITLE3=Paul Buckmaster / Spider Research / Introduccion (We Did It) / The Prop
+			// TTITLE3=osition
+			// TTITLE8=Paul Buckmaster / Introduccion (Escape To Nowhere) / Scanner Room / Cap
+			// TTITLE8=ture And Sedation
+						
+			// STOCKER LE PREMIER TITRE
 			PtrNameTrack = strchr( Larrbuf[ Cpt ], '=' );
 			PtrNameTrack ++;
+			g_string_append_printf( gstr, "%s", PtrNameTrack );
+			
+			// NUMERO DU TTITLE 'xx'
+			NumTrack = CdCurl_get_numtrack_next( Larrbuf[ Cpt ] );
+			
+			// NOUVEL ALGO: BUG TICROB SOLVED
+			while( NumTrack == CdCurl_get_numtrack_next( Larrbuf[ Cpt +1 ] )) {
+							
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print( "%02d  %s\n", Cpt, Larrbuf[ Cpt +1 ] );
+				
+				PtrNameTrack = strchr( Larrbuf[ Cpt +1 ], '=' );
+				PtrNameTrack ++;
+				g_string_append_printf( gstr, "%s", PtrNameTrack );
+				Cpt ++;
+			}
+			
+			PtrNameTrack = gstr->str;
 			
 			Audio = ( CD_AUDIO * )g_malloc0( sizeof( CD_AUDIO ));
 			Audio->EtatPlay                 = CD_ETAT_PLAY_ATTENTE;
@@ -887,10 +948,7 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			Audio->Num_Track		= Track + 1;
 			Audio->Str_Track		= g_strdup_printf ( "%02d", Track + 1 );
 			Audio->Duree			= g_strdup( VarSector.ListSector[ Track ].StrTime );
-			Audio->NameSong			= libutils_dup_chomp(  PtrNameTrack );
-			if( NULL != ( PtrNameTrack = strchr( Audio->NameSong, '/' ))) {
-				*PtrNameTrack = '-';
-			}
+			Audio->NameSong			= libutils_dup_chomp( PtrNameTrack );
 
 			VarSector.ListSector[ Track ].Title = g_strdup( Audio->NameSong	);
 		
@@ -942,6 +1000,9 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			view.TitleCD = g_strdup_printf( "%s", EnteteCD.TitleCD );
 			
 			Track ++;
+			
+			g_string_free (gstr, TRUE);
+			gstr = NULL;
 		}
 	}
 	CdCurl_set_datas_buffer( gstr_buffer_title, gstr_buffer_title_time, gstr_buffer_artist_title_time );
@@ -1089,14 +1150,35 @@ void CdCurl_set_datas_for_cdcue( void )
 void CdCurl_set_datas_for_cdcue_two( void )
 {
 	gint	Track;
+	gchar	*PtrNameTrack = NULL;
+	
+	PRINT("");
 	
 	BaseIoctl.Performer = g_strdup( EnteteCD . TitleCD );
 	BaseIoctl.Title     = g_strdup( EnteteCD . TitleCD );
 	BaseIoctl.File      = g_strdup_printf ("%s.wav", EnteteCD . TitleCD);
 	
 	for( Track = 0; Track < VarSector.TotalTracks; Track++ ) {
+		// 
+		// BUG FIND BY @TICROB: SOLVED
+		// TEST ALLOC OF: 
+		// 	BaseIoctl.Cue [ Track ].Performer
+		//	BaseIoctl.Cue [ Track ].Title
+		// 
+		if( NULL != BaseIoctl.Cue [ Track ].Performer ) {
+			g_free( BaseIoctl.Cue [ Track ].Performer );
+			BaseIoctl.Cue [ Track ].Performer = NULL;
+		}
+		if( NULL != BaseIoctl.Cue [ Track ].Title ) {
+			g_free( BaseIoctl.Cue [ Track ].Title );
+			BaseIoctl.Cue [ Track ].Title = NULL;
+		}
 		BaseIoctl.Cue [ Track ].Performer = g_strdup( EnteteCD . TitleCD );
 		BaseIoctl.Cue [ Track ].Title     = g_strdup( VarSector.ListSector[ Track ].Title );
+
+		while( NULL != ( PtrNameTrack = strchr( BaseIoctl.Cue [ Track ].Title, '/' ))) {
+			*PtrNameTrack = '-';
+		}
 	}
 	
 	cdcue_print_base_ioctl();
@@ -1132,9 +1214,9 @@ gboolean CdCurl_get_info_cd( void )
 		VarSector.StrDiscID    = g_strdup( Larrbuf[ 0 ] );
 		VarSector.GStrCdDiscID = g_string_new( NULL );
 		for( Cpt = 1; Larrbuf[ Cpt ]; Cpt ++ ) {
-			g_string_sprintfa( VarSector.GStrCdDiscID, "%s", Larrbuf[ Cpt ] );
+			g_string_append_printf( VarSector.GStrCdDiscID, "%s", Larrbuf[ Cpt ] );
 			if( NULL != Larrbuf[ Cpt +1 ] )
-				g_string_sprintfa( VarSector.GStrCdDiscID, "+" );
+				g_string_append_printf( VarSector.GStrCdDiscID, "+" );
 		}
 		VarSector.LenDisc      = atoi( Larrbuf[ Cpt -1 ] );
 		g_strfreev( Larrbuf );
