@@ -33,11 +33,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -65,6 +60,7 @@ CONF	Conf = { NULL };
 VAR_CONFIG ConfigSaveToRest;	// Pour les restitutions par defaut
 VAR_CONFIG Config = {
 	FALSE,		// BoolConfigOk
+	1,		// gulong	UsesOfXcfa;	// 0 to G_MAXULONG ( 18446744073709551615 )
 	0,		// WinPos_X
 	0,		// WinPos_Y
 	800,		// WinWidth
@@ -155,7 +151,10 @@ VAR_CONFIG Config = {
 	FALSE,		// gboolean	BoolCheckbuttonEndOfConvert
 	NULL,		// gchar	*PathMusicFileEndOfConvert
 	NULL,		// gchar	*FileMusicFileEndOfConvert
-	NULL		// gchar	*StringCommentCD
+	NULL,		// gchar	*StringCommentCD
+	
+	FALSE		// gboolean	BoolLogCdparanoiaModeExpert
+
 };
 
 
@@ -281,7 +280,7 @@ gboolean config_read_value_bool( gchar *p_Search, gboolean *p_ValueBool )
 	}
 	return( FALSE );	
 }
-// LECTURE NUMERIQUE
+// LECTURE NUMERIQUE INT
 // 
 gboolean config_read_value_atoi( gchar *p_Search, gint *p_ValueAtoi, gint p_Min, gint p_Max )
 {
@@ -311,6 +310,36 @@ gboolean config_read_value_atoi( gchar *p_Search, gint *p_ValueAtoi, gint p_Min,
 	}
 	return( FALSE );	
 }
+// LECTURE NUMERIQUE INT
+// 
+gboolean config_read_value_atol( gchar *p_Search, gulong *p_ValueAtoi, gint p_Min, gint p_Max )
+{
+	gchar	*Ptr = NULL;
+	gint	Cpt;
+	
+	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
+		
+		// Si commentaire ou ligne vide alors ligne suivante
+		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
+		
+		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
+			if( NULL != ( Ptr = config_get_target( Conf.Larrbuf[ Cpt ] ))) {
+				*p_ValueAtoi = atol( Ptr );
+				g_free( Ptr );
+				Ptr = NULL;
+				if( p_Min > -1 && *p_ValueAtoi < p_Min ) *p_ValueAtoi = p_Min;
+				if( p_Max > -1 && *p_ValueAtoi > p_Max ) *p_ValueAtoi = p_Max;
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					config_print_data( p_Search );
+					g_print( "%lu / %lu  ;-)\n", *p_ValueAtoi ? *p_ValueAtoi : 0, G_MAXULONG );
+				}
+				*Conf.Larrbuf[ Cpt ] = '\0';
+				return( TRUE );
+			}
+		}
+	}
+	return( FALSE );	
+}
 // LECTURE PATHNAME
 // 
 gboolean config_read_value_path( gchar *p_Search, gchar **p_ValuePath, gchar *p_default )
@@ -376,6 +405,75 @@ gboolean config_read_value_str( gchar *p_Search, gchar **p_ValueStr )
 	}
 	return( FALSE );	
 }
+// 
+// CALL:
+// 	config_read_value_tab( "HOURS_MONDAY", Config.HoursMonday, 4 );
+// 
+gboolean config_read_value_tab( gchar *p_Search, gint p_ValueTab[], gint p_max_tab )
+{
+	gchar	*Ptr = NULL;
+	gint	Cpt;
+	
+	// IF NOT INIT IN TAB:
+	// 	*(p_ValueTab +0) = 0;
+	// 	*(p_ValueTab +1) = 0;
+	// 	*(p_ValueTab +2) = 0;
+	// 	*(p_ValueTab +3) = 0;
+	
+	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
+		
+		// Si commentaire ou ligne vide alors ligne suivante
+		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
+		
+		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
+
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				config_print_data( p_Search );
+
+			if( NULL != (Ptr = strchr( Conf.Larrbuf[ Cpt ], '=' ))) {
+				
+				gchar	**LarrbufLine = NULL;
+				gint	Indice;
+				
+				// POINTEUR SUR LA PREMIERE OCCURANCE
+				Ptr ++;
+				while( *Ptr == ' ' || *Ptr == '\t' ) Ptr ++;
+				
+				// *Ptr IS VALID ?
+				if( *Ptr != '\0' ) {
+					
+					// HOURS_MONDAY                  = 435 690 720 975
+					// HOURS_SATURDAY                = 0 0 0 0
+					LarrbufLine = g_strsplit( Ptr, " ", 0 );
+				
+					// INDICE: 0 .. p_max_tab
+					for( Indice = 0; LarrbufLine[ Indice ] && Indice < p_max_tab; Indice ++ ) {
+					
+						*(p_ValueTab +Indice) = (gint)atoi( LarrbufLine[ Indice ] );
+					
+						if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+							g_print ("%04d (%02d:%02d)  ",
+								*(p_ValueTab +Indice),
+								*(p_ValueTab +Indice) / 60,
+								*(p_ValueTab +Indice) % 60
+								);
+						}
+					}
+				
+					g_strfreev( LarrbufLine );
+					LarrbufLine = NULL;
+				}
+			}
+			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print( "\n" );
+			
+			*Conf.Larrbuf[ Cpt ] = '\0';
+			return( TRUE );	
+		}
+	}
+	return( FALSE );	
+}
 // 	
 // 	
 void config_close_conf_file( void )
@@ -454,6 +552,13 @@ void config_read( void )
 	
 	if( TRUE == config_open_conf_file( PathNameConfig )) {
 		
+		// READ ATOL
+		// 
+		config_read_value_atol( "USES_OF_XCFA",				&Config.UsesOfXcfa,       		 0,	-1 );
+		if( Config.UsesOfXcfa < G_MAXULONG )
+			Config.UsesOfXcfa ++;
+		else	Config.UsesOfXcfa = 0;
+		
 		// READ ATOI
 		// 
 		config_read_value_atoi( "WIN_POS_X",				&Config.WinPos_X,       		 0,	-1 );
@@ -514,6 +619,7 @@ void config_read( void )
 		config_read_value_bool( "TAGS_COMMENT",				&Config.BoolCommentTag );
 		config_read_value_bool( "BOOL_ETAT_EXPANDER_CD",		&Config.BoolEtatExpanderCd );
 		config_read_value_bool( "BOOL_PLAY_MUSIC_END_CONVERT",		&Config.BoolCheckbuttonEndOfConvert );
+		config_read_value_bool( "BOOL_LOG_CDPARANOIA_MODE_EXPERT",	&Config.BoolLogCdparanoiaModeExpert);
 		
 		// READ PATH
 		// 
@@ -588,6 +694,7 @@ void config_read( void )
 		config_verif_path( &Config.PathLoadImg,			NULL );
 		config_verif_path( &Config.PathSaveImg,			NULL );
 		config_verif_path( &Config.PathMusicFileEndOfConvert,	NULL );
+
 	}
 	if( NULL != PathNameConfig ) {
 		g_free( PathNameConfig );
@@ -610,6 +717,7 @@ void config_save( void )
 		fprintf( fp,   "## File of configuration to : %s\n", PACKAGE_STRING);
 		fprintf( fp,   "############################################################################\n" );
 		fprintf( fp, "\n" );
+		fprintf( fp, "USES_OF_XCFA                        = %lu\n",Config.UsesOfXcfa );
 		fprintf( fp, "WIN_POS_X                           = %d\n", Config.WinPos_X );
 		fprintf( fp, "WIN_POS_Y                           = %d\n", Config.WinPos_Y );
 		fprintf( fp, "WIN_WIDTH                           = %d\n", Config.WinWidth );
@@ -733,6 +841,7 @@ void config_save( void )
 		fprintf( fp, "PATH_MUSIC_END_CONVERT              = %s\n", Config.PathMusicFileEndOfConvert != NULL ? Config.PathMusicFileEndOfConvert : "" );
 		fprintf( fp, "FILE_NAME_MUSIC_END_CONVERT         = %s\n", Config.FileMusicFileEndOfConvert != NULL ? Config.FileMusicFileEndOfConvert : "" );
 		fprintf( fp, "STRING_COMMENT_CD                   = %s\n", Config.StringCommentCD  != NULL ? Config.StringCommentCD : "" );
+		fprintf( fp, "BOOL_LOG_CDPARANOIA_MODE_EXPERT     = %s\n", Config.BoolLogCdparanoiaModeExpert == TRUE ? "TRUE" : "FALSE" );
 		
 		// TODO: RESERVED
 		// g_sprintf( String, "%08lx", ret );
