@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <pthread.h>
 #include <sys/types.h>
@@ -267,9 +262,10 @@ void conv_reset_struct (void *p_func)
 			
 	conv.bool_stop = FALSE;
 
-	if (conv.TmpRep) g_free (conv.TmpRep);
-	conv.TmpRep = NULL;
-
+	if( NULL != conv.TmpRep ) {
+		g_free (conv.TmpRep);
+		conv.TmpRep = NULL;
+	}
 	conv.code_fork_conv = -1;
 	conv.code_fork_extract = -1;
 	conv.handler_timeout_conv = 0;
@@ -325,7 +321,7 @@ void conv_with_lsdvd_ARGS (gchar **args)
 gboolean conv_with_mplayer_ARGS (gchar **args, TYPE_CONV p_TypeConv)
 {
 	gint		pos = 0;
-	gint		fd;
+	gint		fd = -1;
 	gint		size;
 	gchar		buf [ CONV_MAX_CARS + 10 ];
 	gboolean	BoolRet = TRUE;
@@ -341,13 +337,14 @@ gboolean conv_with_mplayer_ARGS (gchar **args, TYPE_CONV p_TypeConv)
 	conv.conversion_percent = 0.0;
 	conv.bool_percent_conv = TRUE;
 	fd = conv_call_exec (args, &conv.code_fork_conv, STDOUT_FILENO);
-
+	
 	/* Ne pas stopper mplayer */
 	/* conv.code_fork_conv = -1; */
 	
 	do {
 		pos = -1;
 		do {
+		
 			pos++;
 			if (pos >= CONV_MAX_CARS) {
 				PRINT_FUNC_LF();
@@ -361,6 +358,11 @@ gboolean conv_with_mplayer_ARGS (gchar **args, TYPE_CONV p_TypeConv)
 				BoolErreurMplayer = TRUE;
 				break;
 			}
+			if (strstr(buf,"relocation error")) {
+				BoolRet = FALSE;
+				BoolErreurMplayer = TRUE;
+				break;
+			}
 			
 		} while (FALSE == conv.bool_stop && (buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
 		
@@ -690,14 +692,11 @@ void conv_with_wavpack_ARGS (gchar **args)
 {
 	gint       pos = 0;
 	gboolean   BoolPass = FALSE;
-	
 	gint       fd;
 	gint       size;
 	gchar      buf [ CONV_MAX_CARS + 10 ];
 	gchar     *ptr = NULL;
 	gint       percent;
-	
-	gint	   PassMess = 0;
 
 	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
 
@@ -764,34 +763,9 @@ void conv_with_wavpack_ARGS (gchar **args)
 				BoolPass = TRUE;
 			}
 		}
-		else if ((ptr = strstr (&buf[0], "original md5 signature:"))) {
-			
-			PassMess = 1;
-			// logs_write_datas ("\t");
-			// logs_writeln_datas (buf);
-		}
-		else if ((ptr = strstr (&buf[0], "created"))) {
-			
-			PassMess = 2;
-			// logs_write_datas ("\t");
-			// logs_writeln_datas (buf);
-		}
-		else if (PassMess == 0) {
-			PassMess = 3;
-		}
 
 	} while (FALSE == conv.bool_stop && size != 0);
-	
-	switch (PassMess) {
-	case 0 :
-	case 1 :
-	case 2 :
-		break;
-	case 3 :
-		// logs_writeln_datas (_("Wav to Wavpack"));
-		break;
-	}
-	
+		
 	if (BoolPass == FALSE) {
 		
 		percent = 100;
@@ -999,7 +973,8 @@ void conv_with_ogg123_ARGS (gchar **args)
 	gchar  buf [ CONV_MAX_CARS + 10 ];
 	gint   Dummy;
 	gint   Min = -1, Sec = -1, Cent = -1;
-	gint   Code = -1, TT_Sector = -1;
+	// gint   Code = -1;
+	gint   TT_Sector = -1;
 
 	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
 
@@ -1031,7 +1006,7 @@ void conv_with_ogg123_ARGS (gchar **args)
 		/*
 		Time: 00:39,17 [03:57,86] of 04:37,03  (190,3 kbit/s)  Output Buffer 100,0%
 		*/
-		Code = -1;
+		// Code = -1;
 
 		if (TT_Sector == -1) {
 			sscanf(buf, "Time: %d:%d,%d [%d:%d,%d] of %d:%d,%d",
@@ -1220,7 +1195,7 @@ void conv_with_normalise_get_PEAK_RMS_GROUP_ARGS (gchar **args)
 	conv.code_fork_conv = -1;
 	conv.conversion_percent = 0.0;
 }
-// REPLAGAN
+// REPLAGAIN
 // 
 void conv_with_replaygain_ARGS (gchar **args)
 {
@@ -1762,16 +1737,13 @@ void conv_with_wvunpack_ARGS (gchar **args)
 		original md5:  2b74aed5a5d62d1c3b0e6b96d5147cc9
 		unpacked md5:  2b74aed5a5d62d1c3b0e6b96d5147cc9
 		restored ./20.wav in 17.23 secs (lossless, 26.45%)
-		*/
 		else if ((ptr = strstr (&buf[0], "original md5:"))) {
-			// logs_writeln_datas (buf);
 		}
 		else if ((ptr = strstr (&buf[0], "unpacked md5:"))) {
-			// logs_writeln_datas (buf);
 		}
 		else if ((ptr = strstr (&buf[0], "restored"))) {
-			// logs_writeln_datas (buf);
 		}
+		*/
 	} while (FALSE == conv.bool_stop && size != 0);
 
 	close(fd);
@@ -2359,6 +2331,11 @@ gboolean conv_exec_extract (gboolean WithParameter, TYPE_CONV type_conv, gchar *
 		g_print ("!  --Without Expert Parameters--\n");
 		g_print ("!  %s\n", info);
 		g_print ("!-----------------------------------------------------------!\n");
+		g_print ("!  ");
+		for (pos = 0; conv.ArgExtract[ pos ] != NULL; pos ++) {
+			g_print ("%s ", conv.ArgExtract[ pos ]);
+		}
+		g_print ("\n!-----------------------------------------------------------!\n");
 
 		for (pos = 0; conv.ArgExtract[ pos ] != NULL; pos ++) {
 			g_print ("ArgExtract[ %02d ] = %s\n", pos, conv.ArgExtract[ pos ]);
