@@ -31,11 +31,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
 #include <string.h>
