@@ -1642,7 +1642,17 @@ gint dvd_get_value_normalise_dvd (void)
 	return (gtk_combo_box_get_active (var_dvd.Adr_combobox_normalise_dvd));
 }
 // 
+// SOLVED
+// 	Debian Bug report logs - #673640
+// 	xcfa: XCFA crashes when the CD is ejected
+// 	http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=673640
 // 
+void on_button_eject_dvd_realize( GtkWidget *widget, gpointer user_data )
+{
+	// g_print( "on_button_eject_dvd_realize\n" );
+	// g_print( "\tscan_get_glist() = %p\n", scan_get_glist () );
+	gtk_widget_set_sensitive( widget, scan_get_glist() == NULL ? FALSE : TRUE );
+}
 void on_button_eject_dvd_clicked (GtkButton *button, gpointer user_data)
 {
 	dvd_remove_GtkTree ();
