@@ -163,30 +163,41 @@ typedef struct {
 	TAGS			*tags;					// Tags
 } INFO_AC3;
 
-// 
-// ---------------------------------------------------------------------------
-//  F I C    M P 3 O G G
-// ---------------------------------------------------------------------------
-// 
+/*
+	M P 3
+	
+	TYPE:	ABR
+	DEBIT:	32 40 48 56 64 80 96 112 128 160 192 224 320
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
 
-typedef struct {
-	gint			type;					// 
-	gint			debit[4];				// 
-	gint			mode[4];				// 
-	gboolean		BoolChanged;				// 
-} TYPE_MP3OGG;
+	TYPE:	CBR
+	DEBIT:	32 40 48 56 64 80 96 112 128 160 192 224 320
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+
+	TYPE:	VBR
+	DEBIT:	preset medium / preset standard / preset extreme / preset fast standard / preset fast extreme / V0 V1 V2 V3 V4 V5 V6 V7 V8 V9
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+
+	TYPE:	VBR-NEW
+	DEBIT:	NONE / preset medium / preset standard / preset extreme / preset fast standard / preset fast extreme / V0 V1 V2 V3 V4 V5 V6 V7 V8 V9
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+
+	O G G
+
+	DEBIT:		45  kbit/s / 64  kbit/s / 80  kbit/s / 96  kbit/s / 112  kbit/s / 128  kbit/s / 160  kbit/s / 192  kbit/s / 224  kbit/s / 256  kbit/s / 320  kbit/s / 
+			Qualite -1 -Moins bonne qualite / Qualite  0 / Qualite  1 / Qualite  2 / Qualite  3 -Defaut / Qualite  4 / Qualite  5 / Qualite  6 / Qualite  7 / Qualite  8 / Qualite  9 / Qualite  10 -Meilleure qualite
+	MANAGED:	Oui / Non
+	DOWNMIX:	Mono force / Stereo
+*/
 
 typedef struct {
 	gboolean		 Bool_Conv;				// TRUE si conversion
-	gchar			*New_src;				// Temporaire: Pathname
 	gchar			*destwav;				// Temporaire: Pathname
 	gchar			*destsox;				// Temporaire: Pathname
 	gchar			*destmp3;				// Temporaire: Pathname
 	gchar			*destogg;				// Temporaire: Pathname
 	gchar			*destfile;				// Destination du fichier apres rectification
 	gchar			*Bitrate;				// Le bitrate actuel
-	TYPE_MP3OGG		Lame;					// 
-	TYPE_MP3OGG		Oggenc;					// 
 } CONV_FIC_MP3OGG;
 
 // 
@@ -416,7 +427,15 @@ typedef struct {
 	CONV_FIC_WAV		*PConvWav;				// Pointeur pour conversion WAV TO WAV
 	CONV_FIC_MP3OGG		*PConvMp3Ogg;				// Pointeur pour modification bitrate mp3 et ogg
 	TYPE_REMOVE_STRUCT	 BoolRemove;				// TRUE si suppression de la liste sinon FALSE
-	TYPE_MP3OGG		 TypeMp3Ogg;				// type, debit, mode
+
+	// MP3: DEBIT MODE
+	gint			Mp3_Debit;				// 
+	gint			Mp3_Mode;				// 
+	// OGG: DEBIT MANAGED DOWNMIX
+	gint			Ogg_Debit;				// 
+	gint			Ogg_Managed;				// 
+	gint			Ogg_Downmix;				// 
+	gboolean		BoolChanged;				// 
 } DETAIL;
 
 extern GList *entetefile;						// pointeur sur DETAIL
@@ -524,12 +543,12 @@ typedef struct {
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggSize;
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggTime;
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggName;
-	GtkComboBox		*Adr_Widget_Lame_abr_cbr_vbr;
-	GtkComboBox		*Adr_Widget_Lame_bitrate;		
-	GtkComboBox		*Adr_Widget_Lame_Mode;
-	GtkComboBox		*Adr_Widget_Oggenc_bitrate;
-	GtkComboBox		*Adr_Widget_Oggenc_managed;
-	GtkComboBox		*Adr_Widget_Oggenc_downmix;
+	// GtkComboBox		*Adr_Widget_Lame_abr_cbr_vbr;
+	// GtkComboBox		*Adr_Widget_Lame_bitrate;		
+	// GtkComboBox		*Adr_Widget_Lame_Mode;
+	// GtkComboBox		*Adr_Widget_Oggenc_bitrate;
+	// GtkComboBox		*Adr_Widget_Oggenc_managed;
+	// GtkComboBox		*Adr_Widget_Oggenc_downmix;
 } VAR_FILE_MP3OGG;
 
 extern VAR_FILE_MP3OGG var_file_mp3ogg;
@@ -636,6 +655,7 @@ void		FileMp3Ogg_set_flag_buttons( void );
 void		FileMp3Ogg_affiche_glist( void );
 gboolean	FileMp3Ogg_del_file_clicked( void );
 void		FileMp3Ogg_change_parameters( void );
+void		FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs );
 // 
 // ---------------------------------------------------------------------------
 //  FILE_MP3OGG_CONV.C
