@@ -59,22 +59,17 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
+#include <pthread.h>
 
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
 #endif
 
-#include <pthread.h>
 #include "global.h"
 #include "file.h"
 #include "replaygain.h"
