@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -59,12 +54,15 @@
 #include "win_scan.h"
 #include "win_info.h"
 #include "popup_systray.h"
+#include "popup.h"
 #include "file.h"
 
 
 
 
 
+gboolean	BoolErrMplayer = FALSE;
+gboolean	BoolErrSox = FALSE;
 
 // 
 // 
@@ -85,18 +83,18 @@ static void filemp3oggconv_thread (void *arg)
 	conv.bool_thread_conv  = TRUE;
 
 	list = g_list_first (entetefile);
-	while (FALSE == conv.bool_stop && list) {
+	while( NULL != list && FALSE == conv.bool_stop ) {
+
 		if (NULL != (detail = (DETAIL *)list->data)) {
-			
+
 			if (FILE_IS_OGG != detail->type_infosong_file_is && FILE_IS_MP3 != detail->type_infosong_file_is) {
 				list = g_list_next(list);
 				continue;
 			}
-			if (FALSE == detail->TypeMp3Ogg.BoolChanged) {
+			if( FALSE == detail->BoolChanged ) {
 				list = g_list_next(list);
 				continue;
 			}
-			
 			PConvMp3Ogg = detail->PConvMp3Ogg;
 			
 			if (FILE_IS_MP3 == detail->type_infosong_file_is) {
@@ -108,13 +106,16 @@ static void filemp3oggconv_thread (void *arg)
 				*  SOURCE MP3 -> DESTINATION WAV
 				*  ------------------------------------
 				*/
-				g_print ("SOURCE MP3<%s>\n", detail->namefile);
-				g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destwav);
-
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					g_print ("SOURCE MP3<%s>\n", detail->namefile);
+					g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destwav);
+				}
+				
 				pos = filelc_get_command_line_nice ();
 				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
 				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
 				conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
+				conv.ArgConv [ pos++ ] = g_strdup ("-novideo");
 				conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", detail->namefile);
 				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
 				conv.ArgConv [ pos++ ] = g_strdup ("pcm");
@@ -129,46 +130,60 @@ static void filemp3oggconv_thread (void *arg)
 				conv_to_convert (FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
 				filelc_get_command_line_remove ();
 				
-				/* SOX wav TO soxwav
-				*  RENAME soxwav TO wav
-				*/
-				if (InfoMp3->mpeg_is != MPEG_1) {
-
-					g_print ("SOURCE MP3<%s>\n", PConvMp3Ogg->destwav);
-					g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destsox);
-					conv_with_sox_get_param( PConvMp3Ogg->destwav, PConvMp3Ogg->destsox, "44100", "2", "16" );
-					conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-					filelc_get_command_line_remove ();
-					conv_copy_src_to_dest (PConvMp3Ogg->destsox, PConvMp3Ogg->destwav);
+				if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav )) {
 					
-					// conv.encode_completed ++;
+					/* SOX wav TO soxwav
+					*  RENAME soxwav TO wav
+					*/
+					if (InfoMp3->mpeg_is != MPEG_1) {
+
+						if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+							g_print ("SOURCE MP3<%s>\n", PConvMp3Ogg->destwav);
+							g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destsox);
+						}
+						conv_with_sox_get_param( PConvMp3Ogg->destwav, PConvMp3Ogg->destsox, "44100", "2", "16" );
+						conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
+						filelc_get_command_line_remove ();
+						conv_copy_src_to_dest (PConvMp3Ogg->destsox, PConvMp3Ogg->destwav);
+					
+						// conv.encode_completed ++;
+					}
+					
+					if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav ) && libutils_get_size_file( PConvMp3Ogg->destwav ) > 0 ) {
+						/* lame SOURCE WAV -> DESTINATION MP3
+						*  ----------------------------------
+						*/
+						if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+							g_print ("SOURCE WAV%s>\n", PConvMp3Ogg->destwav);
+							g_print ("DEST   MP3<%s>\n", PConvMp3Ogg->destmp3);
+						}
+						param_filelc.type_conv            = LAME_WAV_TO_MP3;
+						param_filelc.With_CommandLineUser = FALSE;
+						param_filelc.filesrc              = PConvMp3Ogg->destwav;
+						param_filelc.filedest             = PConvMp3Ogg->destmp3;
+						param_filelc.tags                 = InfoMp3->tags;
+						param_filelc.cdrom                = NULL;
+						param_filelc.num_track            = NULL;
+						param_filelc.BoolSetBitrate       = TRUE;
+						param_filelc.PtrStrBitrate        = popup_get_param_mp3( detail->Mp3_Debit, detail->Mp3_Mode );
+
+						filelc_get_command_line (&param_filelc);
+						conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+						filelc_get_command_line_remove ();
+
+						/* copy SOURCE MP3 -> DESTINATION MP3
+						*  ----------------------------------
+						*/
+						if (FALSE == conv.bool_stop) {
+							conv_copy_src_to_dest (PConvMp3Ogg->destmp3, PConvMp3Ogg->destfile);
+						}
+					}
+					else {
+						BoolErrSox = TRUE;
+					}
 				}
-
-				/* lame SOURCE WAV -> DESTINATION MP3
-				*  ----------------------------------
-				*/
-				g_print ("SOURCE WAV%s>\n", PConvMp3Ogg->destwav);
-				g_print ("DEST   MP3<%s>\n", PConvMp3Ogg->destmp3);
-
-				param_filelc.type_conv            = LAME_WAV_TO_MP3;
-				param_filelc.With_CommandLineUser = FALSE;
-				param_filelc.filesrc              = PConvMp3Ogg->destwav;
-				param_filelc.filedest             = PConvMp3Ogg->destmp3;
-				param_filelc.tags                 = InfoMp3->tags;
-				param_filelc.cdrom                = NULL;
-				param_filelc.num_track            = NULL;
-				param_filelc.BoolSetBitrate       = TRUE;
-				param_filelc.PtrStrBitrate        = options_get_params (LAME_WAV_TO_MP3, detail);
-
-				filelc_get_command_line (&param_filelc);
-				conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-				filelc_get_command_line_remove ();
-
-				/* copy SOURCE MP3 -> DESTINATION MP3
-				*  ----------------------------------
-				*/
-				if (FALSE == conv.bool_stop) {
-					conv_copy_src_to_dest (PConvMp3Ogg->destmp3, PConvMp3Ogg->destfile);
+				else {
+					BoolErrMplayer = TRUE;
 				}
 			}
 			else if (FILE_IS_OGG == detail->type_infosong_file_is) {
@@ -178,9 +193,10 @@ static void filemp3oggconv_thread (void *arg)
 				/* ogg123 SOURCE OGG -> DESTINATION WAV
 				*  ------------------------------------
 				*/
-				g_print ("SOURCE MP3<%s>\n", detail->namefile);
-				g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destwav);
-			
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					g_print ("SOURCE MP3<%s>\n", detail->namefile);
+					g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destwav);
+				}
 				pos = filelc_get_command_line_nice ();
 				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
 				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
@@ -199,31 +215,38 @@ static void filemp3oggconv_thread (void *arg)
 				conv_to_convert (param_filelc.With_CommandLineUser, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
 				filelc_get_command_line_remove ();
 								
-				/* oggenc SOURCE WAV -> DESTINATION OGG
-				*  ----------------------------------
-				*/
-				g_print ("SOURCE WAV%s>\n", PConvMp3Ogg->destwav);
-				g_print ("DEST   MP3<%s>\n", PConvMp3Ogg->destogg);
+				if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav ) && libutils_get_size_file( PConvMp3Ogg->destwav ) > 0 ) {
+					
+					/* oggenc SOURCE WAV -> DESTINATION OGG
+					*  ----------------------------------
+					*/
+					if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+						g_print ("SOURCE WAV%s>\n", PConvMp3Ogg->destwav);
+						g_print ("DEST   MP3<%s>\n", PConvMp3Ogg->destogg);
+					}
+					param_filelc.type_conv            = OGGENC_WAV_TO_OGG;
+					param_filelc.With_CommandLineUser = FALSE;
+					param_filelc.filesrc              = PConvMp3Ogg->destwav;
+					param_filelc.filedest             = PConvMp3Ogg->destogg;
+					param_filelc.tags                 = InfoOgg->tags;
+					param_filelc.cdrom                = NULL;
+					param_filelc.num_track            = NULL;
+					param_filelc.BoolSetBitrate       = TRUE;
+					param_filelc.PtrStrBitrate        = popup_get_param_ogg( detail->Ogg_Debit, detail->Ogg_Managed, detail->Ogg_Downmix );
 
-				param_filelc.type_conv            = OGGENC_WAV_TO_OGG;
-				param_filelc.With_CommandLineUser = FALSE;
-				param_filelc.filesrc              = PConvMp3Ogg->destwav;
-				param_filelc.filedest             = PConvMp3Ogg->destogg;
-				param_filelc.tags                 = InfoOgg->tags;
-				param_filelc.cdrom                = NULL;
-				param_filelc.num_track            = NULL;
-				param_filelc.BoolSetBitrate       = TRUE;
-				param_filelc.PtrStrBitrate        = options_get_params (OGGENC_WAV_TO_OGG, detail);
-
-				filelc_get_command_line (&param_filelc);
-				conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-				filelc_get_command_line_remove ();
+					filelc_get_command_line (&param_filelc);
+					conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+					filelc_get_command_line_remove ();
 				
-				/* copy SOURCE OGG -> DESTINATION MP3
-				*  ----------------------------------
-				*/
-				if (FALSE == conv.bool_stop) {
-					conv_copy_src_to_dest (PConvMp3Ogg->destogg, PConvMp3Ogg->destfile);
+					/* copy SOURCE OGG -> DESTINATION MP3
+					*  ----------------------------------
+					*/
+					if (FALSE == conv.bool_stop) {
+						conv_copy_src_to_dest (PConvMp3Ogg->destogg, PConvMp3Ogg->destfile);
+					}
+				}
+				else {
+					BoolErrMplayer = TRUE;
 				}
 			}
 
@@ -255,7 +278,7 @@ static gint filemp3oggconv_timeout (gpointer data)
 		conv.bool_percent_conv = FALSE;
 	}
 	
-	else if (FALSE == conv.bool_thread_conv) {
+	else if( FALSE == conv.bool_thread_conv ) {
 		
 		GList           *list = NULL;
 		DETAIL          *detail = NULL;
@@ -281,6 +304,14 @@ static gint filemp3oggconv_timeout (gpointer data)
 						PConvMp3Ogg = detail->PConvMp3Ogg = NULL;
 					}
 				}
+				if( FILE_IS_OGG == detail->type_infosong_file_is )
+				{
+					detail->BoolChanged = ( -1 != detail->Ogg_Debit || -1 != detail->Ogg_Managed || -1 != detail->Ogg_Downmix );
+				}
+				if( FILE_IS_MP3 == detail->type_infosong_file_is )
+				{
+					detail->BoolChanged = ( -1 != detail->Mp3_Debit || -1 != detail->Mp3_Mode );
+				}
 			}
 			list = g_list_next(list);
 		}
@@ -301,6 +332,30 @@ static gint filemp3oggconv_timeout (gpointer data)
 		} else {
 			NotifySend_msg (_("XCFA: Modification bitrate"), _("Arret par l'utilisateur"), conv.bool_stop);
 		}
+		if( TRUE == BoolErrMplayer ) {
+			wininfo_create (
+				WindMain,
+				_("Erreur depuis MPLAYER !"),
+				_("Vous pouvez activer XCFA en ligne de commande avec:         "),
+				  "\n",
+				_("$ xcfa -verbose"),
+				  "\n",
+				_("pour consulter le type d'erreur renvoye par mplayer."),
+			  	"");
+		
+		}
+		else if( TRUE == BoolErrSox ) {
+			wininfo_create (
+				WindMain,
+				_("Erreur depuis SOX !"),
+				_("Vous pouvez activer XCFA en ligne de commande avec:         "),
+				  "\n",
+				_("$ xcfa -verbose"),
+				  "\n",
+				_("pour consulter le type d'erreur renvoye par sox."),
+			  	"");
+		
+		}
 	}
 
 	return (TRUE);
@@ -327,7 +382,7 @@ void filemp3oggconv_set_flags_before_conversion (void)
 				detail->PConvMp3Ogg = (CONV_FIC_MP3OGG *)g_malloc0 (sizeof (CONV_FIC_MP3OGG));
 				PConvMp3Ogg = detail->PConvMp3Ogg;
 				
-				if (TRUE == detail->TypeMp3Ogg.BoolChanged) {
+				if( TRUE == detail->BoolChanged ) {
 
 					conv.total_convert += 3;
 
@@ -366,7 +421,7 @@ gboolean filemp3oggconv_is_regul_ok (void) {
 	list = g_list_first (entetefile);
 	while (list) {
 		if (NULL != (detail = (DETAIL *)list->data)) {
-			if (TRUE == detail->TypeMp3Ogg.BoolChanged) {
+			if( TRUE == detail->BoolChanged ) {
 				if (FILE_IS_MP3 == detail->type_infosong_file_is)	bool_mp3 = TRUE;
 				else if (FILE_IS_OGG == detail->type_infosong_file_is)	bool_ogg = TRUE;
 			}
@@ -397,6 +452,7 @@ gboolean filemp3oggconv_is_regul_ok (void) {
 	}
 	if (NULL != str) {
 		wininfo_create (
+			WindMain,
 			_("Package NOT FOUND !"),
 			str,
 		  	"");
@@ -421,7 +477,10 @@ void filemp3oggconv_apply_regul_mp3ogg_by_conv (void)
 		WindScan_set_label ("<b><i>Conversions bitrate ...</i></b>");
 	
 		PopupSystray_set_BoolMainAction (TRUE);
-	
+		
+		BoolErrMplayer = FALSE;
+		BoolErrSox     = FALSE;
+		
 		conv_reset_struct (WindScan_close_request);
 		filemp3oggconv_set_flags_before_conversion ();
 		conv.bool_thread_conv = TRUE;
