@@ -54,11 +54,6 @@ void main_trash (void )
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 #include <string.h>
@@ -144,12 +139,11 @@ gboolean filetrash_test_desktop_is_kde (void)
 #define MAX_CARS_KDE 255
 	gchar		buf   [ MAX_CARS_KDE +1 ];
 	gboolean	BoolRet = FALSE;
-	gint		Dummy;
 	
 	/*
 	KDE_FULL_SESSION
 	*/
-	Dummy = system ("env | grep \"KDE_FULL_SESSION\" > /tmp/tst_kde_full_session.txt");
+	system ("env | grep \"KDE_FULL_SESSION\" > /tmp/tst_kde_full_session.txt");
 	if ((fp = fopen ("/tmp/tst_kde_full_session.txt", "r")) != NULL) {
 		while (fgets (buf, MAX_CARS_KDE, fp) != NULL) {
 			if (strcmp (buf, "KDE_FULL_SESSION") == 0) {
@@ -171,7 +165,6 @@ gboolean filetrash_move_to_trash (gchar *Name)
 	gchar	*NameDest = NULL;
 	gchar	 *Ptr = NULL;
 	gchar	*LineCommand = NULL;
-	gint	Dummy;
 	
 	/*PRINT_FUNC_LF();*/
 	
@@ -183,7 +176,7 @@ gboolean filetrash_move_to_trash (gchar *Name)
 	
 	LineCommand = g_strdup_printf ("mv -f \"%s\" \"%s\"", Name, NameDest);
 	g_print ("To Trash:\n\t%s\n", LineCommand);
-	Dummy = system (LineCommand);
+	system (LineCommand);
 	
 	g_free (LineCommand);
 	LineCommand = NULL;
@@ -211,7 +204,6 @@ void filetrash_test_trash_is_ok (void)
 	gboolean      BoolExistTrashNEW;
 	gchar        *Path = NULL;
 	gchar        *StrTrash = NULL;
-	gint          Dummy;
 	
 	if( TRUE == OptionsCommandLine.BoolVerboseMode )
 		g_print ("\n[ Trash ]\n");
@@ -247,7 +239,7 @@ void filetrash_test_trash_is_ok (void)
 	if (var_filetrash.Bool_kde_full_session == TRUE) {
 		if (BoolExistTrashNEW == FALSE) {
 			StrTrash = g_strdup_printf ("mkdir -p %s", filetrash_get_trash ());
-			Dummy = system (StrTrash);
+			system (StrTrash);
 			g_free (StrTrash);
 			StrTrash = NULL;
 			BoolExistTrashNEW = TRUE;
@@ -261,7 +253,7 @@ void filetrash_test_trash_is_ok (void)
 		else if (BoolExistTrashOLD == FALSE) {
 			var_filetrash.Bool_kde_full_session = TRUE;
 			StrTrash = g_strdup_printf ("mkdir -p %s", filetrash_get_trash ());
-			Dummy = system (StrTrash);
+			system (StrTrash);
 			g_free (StrTrash);
 			StrTrash = NULL;
 			BoolExistTrashNEW = TRUE;
