@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -416,7 +411,6 @@ void GetInfo_cpu_print (void)
 	gchar	*ModelName = NULL;
 
 	ModelName = GetInfo_cpu ();
-
 	HostConf.NbCpu   = sysconf(_SC_NPROCESSORS_ONLN);
 	// g_print ("_SC_NPROCESSORS_CONF : Le nombre de processeurs configure                           = %d\n", (gint)sysconf(_SC_NPROCESSORS_CONF));
 	// g_print ("_SC_NPROCESSORS_ONLN : Le nombre de processeurs actuellement en ligne (disponibles) = %d\n", (gint)sysconf(_SC_NPROCESSORS_ONLN));
@@ -430,18 +424,23 @@ void GetInfo_cpu_print (void)
 		
 		ptruname = g_strdup_printf (
 				"\nINFORMATIONS MACHINE:\n\n"
-				"sysname\t\t= %s\n"
-				"nodename\t= %s\n"
-				"release\t\t= %s\n"
-				"version\t\t= %s\n"
-				"machine\t\t= %s\n"
-				"       \t\t= %d CPU (%d bits)\n"
-				"       \t\t= %s\n",
+				"sysname\t\t = %s\n"
+				"nodename\t = %s\n"
+				"release\t\t = %s\n"
+				"version\t\t = %s\n"
+				"machine\t\t = %s\n"
+				"       \t\t = %d CPU (%d bits)\n"
+				"       \t\t = %s\n",
 			utsname.sysname, utsname.nodename, utsname.release, utsname.version, utsname.machine,
 			HostConf.NbCpu, HostConf.TypeCpu,
 			ModelName);
-		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
 			g_print("%s",ptruname);
+			g_print ("HostConf.NbCpu   = %d CPU\n", HostConf.NbCpu);
+			g_print ("HostConf.TypeCpu = %d Bits\n", HostConf.TypeCpu);
+			g_print ("HostConf.Machine = %s\n", HostConf.Machine);
+			g_print ("\n");
+		}
 	}
 	g_free (ModelName);
 	ModelName = NULL;
@@ -636,8 +635,10 @@ GString *GetInfo_mediainfo (gchar *file)
 		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
 	g_print ("\n");
 	*/
-
-	fd = GetInfo_exec_with_output (args, &VarGet.code_fork, STDOUT_FILENO);
+	// STDIN_FILENO
+	// STDOUT_FILENO
+	// STDERR_FILENO
+	fd = GetInfo_exec_with_output( args, &VarGet.code_fork, STDOUT_FILENO );	
 	do {
 		pos = -1;
 		do {
