@@ -41,6 +41,11 @@ extern	GtkBuilder	*GtkXcfaProjet;
 extern	GtkWidget	*WindMain;
 extern	GtkWidget	*AdrLabelStatusbarGlobal;
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define gettext_noop(x) (x)
+	#define _(String) gettext (String)
+#endif
 
 #define GLADE_GET_OBJECT(OBJ) gtk_builder_get_object (GtkXcfaProjet, OBJ)
 
