@@ -84,7 +84,7 @@ GtkBuilder	*GtkXcfaProjet = NULL;
 GtkWidget	*WindMain = NULL;
 HOST_CONF	 HostConf;
 GtkWidget	*AdrLabelStatusbarGlobal = NULL;
-BaconMessageConnection *connection;
+BaconMessageConnection *connection = NULL;
 
 
 KEYS keys = {
@@ -421,6 +421,10 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 			else if( 0 == strcmp( argv[i], "-help" ) || 0 == strcmp( argv[i], "-h" )) {
 				OptionsCommandLine.BoolHelpMode = TRUE;
 			}
+			// BoolSystray
+			else if( 0 == strcmp( argv[i], "-systray" )) {
+				OptionsCommandLine.BoolSystray = TRUE;
+			}
 		}
 		
 		// STOP ?
@@ -509,8 +513,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	/* Init type system as soon as possible */
 	g_type_init ();
 	g_set_prgname ("xcfa");
-		
-	g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__);
+	
+	PRINT_FUNC_LF();
 	g_print ("\n");
 	g_print ("***************************\n");
 	g_print ("%s %s\n", PACKAGE, VERSION);
@@ -531,6 +535,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 			g_print( "	-help -h	Displays this help section and exits\n" );
 			g_print( "	-version	Displays the version of the program and exits\n" );
 			g_print( "	-verbose	Activate verbose mode\n" );
+			g_print( "	-systray	Activate systray mode\n" );
 		}
 		g_print( "\n" );
 		g_unlink( XCFA_FILE_LOAD );
@@ -680,7 +685,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	libutils_set_default_icone_to_win (WindMain);
 	
 	// SYSTRAY: CREATION DE L'ICONE DE STATUS + INFO-BULLE
-	PopupSystray_init ();
+	if( TRUE == OptionsCommandLine.BoolSystray )
+		PopupSystray_init ();
 	
 	gtk_widget_show (WindMain);
 	
