@@ -28,11 +28,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <sys/types.h>
@@ -116,6 +111,7 @@ void NotifySend_msg( gchar *Title, gchar *Str, gboolean p_BoolStopByUser )
 	if (FALSE == PrgInit.bool_notify_send) {
 		// SUPPRESSION DE L'ALERTE INDIQUANT L'ABSENCE DU PAQUET: LIBNOTIFY-BIN
 		// wininfo_create (
+		// 	WindMain,
 		// 	_("Package NOT FOUND !"),
 		// 	_("(Package libnotify-bin): notify-send NOT EXIST"),
 		//   	"");
