@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
@@ -172,6 +167,7 @@ void options_path_tmp (gchar *path)
 	}
 	else {
 		wininfo_create (
+			WindMain,
 			_("ERREUR: Lieu de stockage non autorise !"),
 			_("Veuillez recommencer."),
 			  "");
@@ -197,13 +193,13 @@ void options_set_all_interne (void)
 }
 // 
 //
-gchar *options_get_params (TYPE_CONV TypeConv, DETAIL *detail)
+gchar *options_get_params( TYPE_CONV TypeConv )
 {
 	if (TypeConv == LAME_WAV_TO_MP3) {
-		return ((gchar *)optionsLame_get_param (detail));
+		return( (gchar *)optionsLame_get_param() );
 	}
 	else if (TypeConv == OGGENC_WAV_TO_OGG || TypeConv == OGGENC_FLAC_TO_OGG) {
-		return ((gchar *)optionsOggenc_get_param (detail));
+		return ((gchar *)optionsOggenc_get_param() );
 	}
 	return ((gchar *)NULL);
 }
