@@ -91,8 +91,9 @@ typedef struct {
 	GtkWidget		*Adr_radiobutton_cdparanoia;			// 
 	GtkWidget		*Adr_radiobutton_libcddb;			// 
 	GtkWidget		*Adr_radiobutton_extract_with_cdparanoia;	// 
-	GtkWidget		*Adr_radiobutton_extract_with_cdda2wav;		// 
+	GtkWidget		*Adr_radiobutton_cdparanoia_mode_2;		// 
 	GtkWidget		*Adr_radiobutton_cdparanoia_mode_expert;	// 
+	GtkWidget		*Adr_radiobutton_extract_with_cdda2wav;		// 
 	GtkWidget		*Adr_label_type_paquege;			// 
 	TYPE_PACKAGE		Type_Package;					// _NONE_ = 0, _DEBIAN_, _TGZ_, _RPM_, _FPM_, _PACKAGE_NOT_FOUND_
 	GtkWidget		*Adr_entry_lame_mp3;				// 
@@ -142,14 +143,15 @@ extern VAR_OPTIONS var_options;
 // 
 void		options_set_all_interne (void);
 gboolean	options_get_entry_is_valid (TYPE_CONV p_verif_conv);
-gchar          *options_get_params (TYPE_CONV TypeConv, DETAIL *detail);
+gchar          *options_get_params( TYPE_CONV TypeConv );
 
 // 
 // ---------------------------------------------------------------------------
 //  OPTIONS_CD.C
 // ---------------------------------------------------------------------------
 // 
-void	OptionsCd_set_entry_and_label( void );
+void		OptionsCd_set_entry_and_label( void );
+gboolean	OptionsCd_get_save_log_mode_expert( void );
 
 
 // 
@@ -167,7 +169,7 @@ void		OptionsInternal_set_datas_interne (COLOR_LINE_COMMAND ColorLineCommand, Gt
 // 
 gchar		*optionsLame_get_str_val_bitrate_abr_vbr_lame (void);
 gchar		*optionsLame_get_str_val_mode_lame (void);
-gchar		*optionsLame_get_param (DETAIL *detail);
+gchar		*optionsLame_get_param( void );
 
 // 
 // ---------------------------------------------------------------------------
@@ -186,7 +188,7 @@ gchar		*optionsMusepack_get_quality_mppenc (void);
 gchar		*optionsOggenc_get_val_bitrate_oggenc (void);
 gboolean	optionsOggenc_get_bool_managed_oggenc (void);
 gboolean	optionsOggenc_get_bool_downmix_oggenc (void);
-gchar		*optionsOggenc_get_param (DETAIL *detail);
+gchar		*optionsOggenc_get_param( void );
 
 // 
 // ---------------------------------------------------------------------------
