@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
@@ -58,6 +53,7 @@ void on_radiobutton_choice_extract_with_clicked (GtkButton *button, gpointer use
 	if (GTK_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_expert) == button)		Config.ExtractCdWith = EXTRACT_WITH_CDPARANOIA_EXPERT;
 	else if (GTK_BUTTON (var_options.Adr_radiobutton_extract_with_cdda2wav) == button)	Config.ExtractCdWith = EXTRACT_WITH_CDDA2WAV;
 	else if (GTK_BUTTON (var_options.Adr_radiobutton_extract_with_cdparanoia) == button)	Config.ExtractCdWith = EXTRACT_WITH_CDPARANOIA;
+	else if (GTK_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_2) == button)		Config.ExtractCdWith = EXTRACT_WITH_CDPARANOIA_MODE_2;
 }
 void on_radiobutton_extract_with_cdparanoia_realize (GtkWidget *widget, gpointer user_data)
 {
@@ -77,6 +73,12 @@ void on_radiobutton_cdparanoia_mode_expert_realize (GtkWidget *widget, gpointer
 	if (Config.ExtractCdWith == EXTRACT_WITH_CDPARANOIA_EXPERT)
 		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_expert), TRUE);
 }
+void on_radiobutton_cdparanoia_mode_2_realize (GtkWidget *widget, gpointer user_data)
+{
+	var_options.Adr_radiobutton_cdparanoia_mode_2 = widget;
+	if (Config.ExtractCdWith == EXTRACT_WITH_CDPARANOIA_MODE_2)
+		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_2), TRUE);
+}
 // 
 // 
 void OptionsCd_set_entry_and_label( void )
@@ -200,12 +202,25 @@ void on_label_stockage_cdaudio_exemple_realize (GtkWidget *widget, gpointer user
 }
 
 
-
-
-
-
-
-
+// 
+// 
+void on_checkbutton_log_cdparanoia_mode_expert_realize( GtkWidget *widget, gpointer user_data )
+{
+	var_cd.Adr_checkbutton_log_cdparanoia_mode_expert = widget;
+	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON(widget), Config.BoolLogCdparanoiaModeExpert );
+}
+// 
+// 
+void on_checkbutton_log_cdparanoia_mode_expert_clicked( GtkButton *button, gpointer user_data )
+{
+	Config.BoolLogCdparanoiaModeExpert = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(var_cd.Adr_checkbutton_log_cdparanoia_mode_expert)) ? TRUE : FALSE;
+}
+// 
+// 
+gboolean OptionsCd_get_save_log_mode_expert( void )
+{
+	return( Config.BoolLogCdparanoiaModeExpert );
+}
 
 
 
