@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
@@ -135,45 +130,31 @@ gboolean bool_do_enter_options_mp3 = TRUE;
 
 // 
 // 
-/*
-	Config.BitrateLameIndice;		// abr .. vbr_new
-	Config.TabBitrateLame[4];		// [ abr | cbr | vbr | vbr_new ]
-	Config.TabModeLame[4];			// [ ModeAbr | ModeCbr | ModeVbr | ModeVbrNew ]
-*/
-gchar *optionsLame_get_param (DETAIL *detail)
+gchar *optionsLame_get_param( void )
 {
 	gchar StrLame[ 1000 ];
 	
 	StrLame [ 0 ] = '\0';
-	
+
 	switch (Config.BitrateLameIndice) {
 	case 0 :
-		if (NULL == detail)
-			strcpy (StrLame, str_abr [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);		
-		else	strcpy (StrLame, str_abr [ detail->TypeMp3Ogg.debit [ detail->TypeMp3Ogg.type ] ]);
+		strcpy (StrLame, str_abr [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);		
 		break;
 	case 1 :
-		if (NULL == detail)
-			strcpy (StrLame, str_cbr [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);
-		else	strcpy (StrLame, str_cbr [ detail->TypeMp3Ogg.debit [ detail->TypeMp3Ogg.type ] ]);
+		strcpy (StrLame, str_cbr [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);
 		break;
 	case 2 :
-		if (NULL == detail)
-			strcpy (StrLame, str_vbr [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);
-		else	strcpy (StrLame, str_vbr [ detail->TypeMp3Ogg.debit [ detail->TypeMp3Ogg.type ] ]);
+		strcpy (StrLame, str_vbr [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);
 		break;
 	case 3 :
-		if (NULL == detail)
-			strcpy (StrLame, str_vbr_new [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);
-		else	strcpy (StrLame, str_vbr_new [ detail->TypeMp3Ogg.debit [ detail->TypeMp3Ogg.type ] ]);
+		strcpy (StrLame, str_vbr_new [ Config.TabBitrateLame[ Config.BitrateLameIndice ] ]);
 		break;
 	}
 	if (Config.TabModeLame[ Config.BitrateLameIndice ] > 0) {
 		if (*StrLame != '\0') strcat (StrLame, " ");
-		if (NULL == detail)
-			strcat (StrLame, str_val_mode [ Config.TabModeLame[ Config.BitrateLameIndice ] ] );
-		else	strcat (StrLame, str_val_mode [ detail->TypeMp3Ogg.mode [ detail->TypeMp3Ogg.type ] ] );
+		strcat (StrLame, str_val_mode [ Config.TabModeLame[ Config.BitrateLameIndice ] ] );
 	}
+	if( *StrLame == '\0' ) return( (gchar *)NULL );
 	return ((gchar *)strdup (StrLame));
 }	
 
