@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
@@ -76,20 +71,15 @@ static 	gchar *val_bitrate_ogg[] = {
 	"--quality=9",
 	"--quality=10"
 	};
+
+
 // 
 // 
-/*
-	Config.BitrateOggenc
-	Config.ManagedOggenc
-	Config.DownmixOggenc
-*/
-gchar *optionsOggenc_get_param (DETAIL *detail)
+gchar *optionsOggenc_get_param( void )
 {
 	gchar StrOggenc[ 1000 ];
 	
-	if (NULL == detail)
-		strcpy (StrOggenc, val_bitrate_ogg [ Config.BitrateOggenc ]);
-	else	strcpy (StrOggenc, val_bitrate_ogg [ detail->TypeMp3Ogg.type ]);
+	strcpy (StrOggenc, val_bitrate_ogg [ Config.BitrateOggenc ]);
 	
 	if (Config.BitrateOggenc < 11 && Config.ManagedOggenc == 0) {
 		if (*StrOggenc != '\0') strcat (StrOggenc, " ");
