@@ -164,6 +164,7 @@ void Parse_debug_print_cd (PARSE_TYPE p_ParseType)
 	}
 }
 */
+
 // 
 // SUPRESSION DES STRUCTURES ET DES GLIST
 //
@@ -568,7 +569,12 @@ void Parse_entry (PARSE_TYPE p_ParseType)
 	
 	if( BoolTagOk == FALSE ) {
 		// SI LISTE VIDE -> CREATION D'UN MINIMUM AVEC LE TITRE
-		Parse_allocate (p_ParseType, CD_TAG_TITLE, NULL);
+		// 
+		// Fwd: Bug#673641: xcfa: Wrong file directory
+		// http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=673641
+		// SOLVED
+		
+		// Parse_allocate (p_ParseType, CD_TAG_TITLE, NULL);
 	}
 	
 	if( TRUE == BoolSet ) {
