@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <sys/types.h>
@@ -109,6 +104,7 @@ void PlayFile_play (gchar *PathNameFile)
 	if (FALSE == extra_get_lecteur_audio_is_ok ()) {
 		PRINT("VEUILLEZ SAISIR UN LECTEUR AUDIO");
 		wininfo_create (
+			WindMain,
 			_("PAS de lecteur audio present"),
 			_("Veuillez installez un lecteur audio."),
 			  "");
@@ -128,9 +124,11 @@ void PlayFile_play (gchar *PathNameFile)
 	PlayFile.Playeur      = g_strdup (extra_get_name_lecteur_audio ());
 	PlayFile.Param        = g_strdup (extra_get_param_name_lecteur_audio ());
 	PlayFile.PathNameFile = g_strdup (PathNameFile);
-	g_print ("\tFILE    : %s\n", PathNameFile);
-	g_print ("\tPLAYEUR : %s\n", PlayFile.Playeur);
-	g_print ("\tPARAM   : %s\n", PlayFile.Param);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("\tFILE    : %s\n", PathNameFile);
+		g_print ("\tPLAYEUR : %s\n", PlayFile.Playeur);
+		g_print ("\tPARAM   : %s\n", PlayFile.Param);
+	}
 	pthread_create (&PlayFile.nmr_tid, NULL ,(void *)PlayFile_thread, (void *)NULL);
 }
 
