@@ -31,11 +31,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
@@ -456,6 +451,7 @@ void pochedraw_set_format( cairo_t *cr )
 	cairo_scale( cr, view.scale, view.scale );
 	cairo_translate( cr, view.x0, view.y0 );
 	cairo_set_source_rgb( cr, 0.0, 0.0, 0.0 );
+	// cairo_set_source_rgb( cr, red/255.0, green/255.0, blue/255.0 );
 	if( FALSE == view.BoolSaveToFile ) {
 		// CONTOUR DE LA FEUILLE
 		// EPAISSEUR
