@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
@@ -84,7 +79,6 @@ void pochesave_write_pdf( gchar *fname, gint width, gint height )
 
 	cs = cairo_pdf_surface_create( fname, width, height );
 	pochedraw_paint( cs );
-	cairo_surface_write_to_png( cs, fname );
 	cairo_surface_destroy( cs );
 }
 // SEE:
@@ -96,7 +90,6 @@ void pochesave_write_ps( gchar *fname, gint width, gint height )
 	
 	cs = cairo_ps_surface_create( fname, width, height );
 	pochedraw_paint( cs );
-	cairo_surface_write_to_png( cs, fname );
 	cairo_surface_destroy( cs );
 }
 // 
@@ -114,6 +107,7 @@ void on_button_save_clicked( GtkButton *button, gpointer user_data )
 	
 	if( NULL == NameSaveFile || '\0' == *NameSaveFile ) {
 		wininfo_create (
+			WindMain,
 			_("Nom de fichier absent  !!"),
 			_("Pour resoudre ce probleme:"),
 			  "\n",
