@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gprintf.h>
@@ -96,8 +91,6 @@ gchar *pocheweb_get_on_web_file_img (gchar *filename)
 	gchar    *name_file = NULL;
 	gint      num;
 	gchar    *LineCommand = NULL;
-	gint	  Dummy;
-
 
 	PRINT_FUNC_LF();
 
@@ -116,7 +109,7 @@ gchar *pocheweb_get_on_web_file_img (gchar *filename)
 	
 	// IMAGE IMPORT
 	LineCommand = g_strdup_printf ("wget --user-agent=\"Mozilla 22.0\" -O %s %s", name_file, filename);
-	Dummy = system (LineCommand);
+	system (LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
 	
@@ -155,7 +148,6 @@ void pocheweb_analyze_file_html (void)
 	gchar   *PtrBegin = NULL;
 	gchar   *PtrEnd = NULL;
 	gchar   *PtrName = NULL;
-	size_t	Dummy;
 	gint	NumFile = 1;
 	
 	PRINT_FUNC_LF();
@@ -173,7 +165,7 @@ void pocheweb_analyze_file_html (void)
 	buffer = g_malloc0 (sizeof (char) * (lenfile + 1024));
 
 	fp = fopen (pocheweb_event.name_index_html, "r");
-	Dummy = fread (buffer, 1, lenfile, fp);
+	fread (buffer, 1, lenfile, fp);
 	fclose (fp);
 
 	// 
@@ -260,7 +252,6 @@ gboolean pocheweb_recup_file_html (gchar *cd_name)
 	gchar     *PtrNew = NULL;
 	gchar     *Ptr = NULL;
 	gchar     *LineCommand = NULL;
-	gint	  Dummy;
 
 	PRINT_FUNC_LF();
 
@@ -299,7 +290,7 @@ http://images.google.com/images?q=Dire%20Straits%20Brothers%20In%20Arms+Dire%20S
 		g_print( "name                           = %s\n", name );				// http://images.google.com/images?q=
 		g_print( "LineCommand=%s\n", LineCommand );	// wget --user-agent="Mozilla 22.0" -O /tmp/XcfaPochette/index.html http://images.google.com/images?q=
 	}
-	Dummy = system (LineCommand);
+	system (LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
 
@@ -357,6 +348,7 @@ static gint pocheweb_timeout (gpointer data)
 
 		if (pocheweb_bool_file_add () == FALSE) {
 			wininfo_create (
+				WindMain,
 				_("Aucun fichier trouve !"),
 				_("Pour resoudre ce probleme:"),
 				  "\n",
@@ -378,6 +370,7 @@ void pocheweb_get (void)
 	
 	if( NULL == StrEntryWeb || '\0' == *StrEntryWeb ) {
 		wininfo_create (
+			WindMain,
 			_("Critere de recherche absent  !!"),
 			_("Pour resoudre ce probleme:"),
 			  "\n",
