@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define gettext_noop(x)( x) 
-#endif
-
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -76,7 +71,6 @@ typedef struct {
 
 
 
-
 #define CASE_POP_MENU_FICHERS 0
 #define MAX_POP_MENU_FICHERS 9
 POP_MENU PopMenuFichiers [ MAX_POP_MENU_FICHERS ] = {
@@ -300,10 +294,9 @@ void popup_callback( GtkMenuItem *menuitem, gpointer user_data )
 }
 // 
 // 
-void popup_make_popup( POP_MENU *p_popup, gint nbr_op)
+void popup_make_popup( POP_MENU *p_popup, gint nbr_op )
 {
 	GtkWidget *menu = NULL;
-	GtkWidget *Attach = NULL;
 	GtkWidget *SubMenu = NULL;
 	gint       cpt = 0;
 	gint       val = 0;
@@ -322,6 +315,7 @@ void popup_make_popup( POP_MENU *p_popup, gint nbr_op)
 			INFO_MP3 *info =( INFO_MP3 *)VarPopup.detail->info;
 			val = info->LevelDbfs.level;
 		}
+		val = val;
 	}
 	
 	menu = gtk_menu_new(  );	
@@ -344,7 +338,7 @@ void popup_make_popup( POP_MENU *p_popup, gint nbr_op)
 			gtk_container_add( GTK_CONTAINER( menu), p_popup[ cpt ].Widget );
 		}
 		else if( p_popup[ cpt ].Op.Type == -3 ) {
-			Attach = p_popup[ cpt ].Widget = gtk_menu_item_new_with_mnemonic( gettext(p_popup[ cpt ].Title) );
+			p_popup[ cpt ].Widget = gtk_menu_item_new_with_mnemonic( gettext(p_popup[ cpt ].Title) );
 			gtk_widget_show( p_popup[ cpt ].Widget );
 			gtk_container_add( GTK_CONTAINER( menu), p_popup[ cpt ].Widget );
 			
@@ -449,20 +443,6 @@ void popup_trash( void )
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 // 
 //
 // POPUP FILE WAV PISTE
@@ -602,7 +582,7 @@ void popup_file_wav_piste( DETAIL *detail)
 	g_signal_connect(( gpointer) ColTrack2,         "activate", G_CALLBACK( on_ColTrack2_activate),         detail  );
 	g_signal_connect(( gpointer) ColTrack4,         "activate", G_CALLBACK( on_ColTrack4_activate),         detail  );
 	g_signal_connect(( gpointer) ColTrack6,         "activate", G_CALLBACK( on_ColTrack6_activate),         detail  );
-	g_signal_connect(( gpointer) ColTrackOriginal,  "activate", G_CALLBACK( on_ColTrackOriginal_activate),   detail  );
+	g_signal_connect(( gpointer) ColTrackOriginal,  "activate", G_CALLBACK( on_ColTrackOriginal_activate),  detail  );
 	
 	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu,       "Menu" );
 	GLADE_HOOKUP_OBJECT( Menu, CellSubMenu,       "CellSubMenu" );
@@ -1326,6 +1306,493 @@ void popup_menu_cd( void )
 
 
 
+// 
+// POPUP MP3 FILES
+// 
+/*
+	TYPE:	ABR
+	DEBIT:	32 40 48 56 64 80 96 112 128 160 192 224 320
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+
+	TYPE:	CBR
+	DEBIT:	32 40 48 56 64 80 96 112 128 160 192 224 320
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+
+	TYPE:	VBR
+	DEBIT:	preset medium / preset standard / preset extreme / preset fast standard / preset fast extreme / V0 V1 V2 V3 V4 V5 V6 V7 V8 V9
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+
+	TYPE:	VBR-NEW
+	DEBIT:	NONE / preset medium / preset standard / preset extreme / preset fast standard / preset fast extreme / V0 V1 V2 V3 V4 V5 V6 V7 V8 V9
+	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
+*/
+DETAIL *Detail_VarOptionsFileOggMp3 = NULL;
+
+gchar *VarOptionsFileMp3[] = {
+	// ABR
+	// 0 .. 13
+	" 32", " 40", " 48", " 56", " 64", " 80", " 96", "112", "128", "160", "192", "224", "256", "320",
+	// CBR
+	// 14 .. 28
+	" 32", " 40", " 48", " 56", " 64", " 80", " 96", "112", "128", "160", "192", "224", "256", "320", "preset insane",
+	// VBR
+	// 29 .. 43
+	"preset medium", "preset standard", "preset extreme", "preset fast standard", "preset fast extreme", gettext_noop("V0 [ meilleure qualite ]"), "V1", "V2", "V3", gettext_noop("V4 [ defaut ]"), "V5", "V6", "V7", "V8", gettext_noop("V9 [ moins bonne qualite ]"),
+	// VBR-NEW
+	// 44 .. 59
+	"NONE", "preset medium", "preset standard", "preset extreme", "preset fast standard", "preset fast extreme", "V0", "V1", "V2", "V3", gettext_noop("V4 [ defaut ]"), "V5", "V6", "V7", "V8", "V9",
+	// MODE
+	// 60 .. 65
+	"Default", "Stereo", "Join Stereo", "Forced Join Stereo", "Duo Channels", "Mono"
+};
+// 
+// 
+void on_type_file_mp3_activate( GtkMenuItem *menuitem, gpointer user_data )
+{
+	gint	Choice = GPOINTER_TO_INT(user_data);
+	
+	if( -1 == Choice ) {
+		// g_print( "REMOVE\n");
+		Detail_VarOptionsFileOggMp3->Mp3_Debit = -1;	// SET DEBIT
+		Detail_VarOptionsFileOggMp3->Mp3_Mode  = -1;	// SET MODE
+		FileMp3Ogg_update_newbitrate( FILE_IS_MP3 );
+		return;
+	}
+	
+	// MP3: DEBIT MODE
+	if( Choice <= 59 )
+		Detail_VarOptionsFileOggMp3->Mp3_Debit = Choice;	// SET DEBIT
+	else	Detail_VarOptionsFileOggMp3->Mp3_Mode  = Choice;	// SET MODE
+	
+	// SELECTIONS DES DEUX OPTIONS OBLIGATOIRE
+	if( -1 == Detail_VarOptionsFileOggMp3->Mp3_Debit )	Detail_VarOptionsFileOggMp3->Mp3_Debit = 0;
+	if( -1 == Detail_VarOptionsFileOggMp3->Mp3_Mode )	Detail_VarOptionsFileOggMp3->Mp3_Mode  = 60;
+	
+	Detail_VarOptionsFileOggMp3->BoolChanged = ( -1 != Detail_VarOptionsFileOggMp3->Mp3_Debit || -1 != Detail_VarOptionsFileOggMp3->Mp3_Mode );
+		
+	FileMp3Ogg_update_newbitrate( FILE_IS_MP3 );
+}
+// 
+// 
+void popup_file_mp3_type( DETAIL *detail, gint p_debit, gint p_mode )
+{
+	GtkWidget	*Menu;
+	GtkWidget	*Type;
+	GtkWidget	*SubMenu;
+	GtkWidget	*Debit;
+	GtkWidget	*Separate;
+	gint		Cpt;
+	gchar		*Str = NULL;
+	
+	Detail_VarOptionsFileOggMp3 = detail;
+	
+	Menu = gtk_menu_new(  );
+	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	// ABR
+	Type = gtk_menu_item_new_with_mnemonic( "Abr" );
+	gtk_widget_show( Type );
+	gtk_container_add( GTK_CONTAINER( Menu), Type );
+		
+		// SUBMENU ABR
+		SubMenu = gtk_menu_new();
+		gtk_menu_item_set_submenu( GTK_MENU_ITEM(Type), SubMenu );
+		for( Cpt = 0; Cpt <= 13; Cpt ++ ) {
+			if( p_debit == Cpt )
+				Str = g_strdup_printf( ">%s", VarOptionsFileMp3[ Cpt ] );
+			else	Str = g_strdup_printf( "  %s", VarOptionsFileMp3[ Cpt ] );
+			Debit = gtk_menu_item_new_with_mnemonic( Str );
+			g_free( Str );
+			Str = NULL;
+			gtk_widget_show( Debit );
+			gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+			g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_mp3_activate), GINT_TO_POINTER(Cpt));
+		}
+	
+	// CBR
+	Type = gtk_menu_item_new_with_mnemonic( "Cbr" );
+	gtk_widget_show( Type );
+	gtk_container_add( GTK_CONTAINER( Menu), Type );
+		
+		// SUBMENU CBR
+		SubMenu = gtk_menu_new();
+		gtk_menu_item_set_submenu( GTK_MENU_ITEM(Type), SubMenu );
+		for( Cpt = 14; Cpt <= 28; Cpt ++ ) {
+			if( p_debit == Cpt )
+				Str = g_strdup_printf( ">%s", VarOptionsFileMp3[ Cpt ] );
+			else	Str = g_strdup_printf( "  %s", VarOptionsFileMp3[ Cpt ] );
+			Debit = gtk_menu_item_new_with_mnemonic( Str );
+			g_free( Str );
+			Str = NULL;
+			gtk_widget_show( Debit );
+			gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+			g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_mp3_activate), GINT_TO_POINTER(Cpt));
+		}
+
+	// VBR
+	Type = gtk_menu_item_new_with_mnemonic( "Vbr" );
+	gtk_widget_show( Type );
+	gtk_container_add( GTK_CONTAINER( Menu), Type );	
+		
+		// SUBMENU VBR
+		SubMenu = gtk_menu_new();
+		gtk_menu_item_set_submenu( GTK_MENU_ITEM(Type), SubMenu );
+		for( Cpt = 29; Cpt <= 43; Cpt ++ ) {
+			if( p_debit == Cpt )
+				Str = g_strdup_printf( ">%s", VarOptionsFileMp3[ Cpt ] );
+			else	Str = g_strdup_printf( "  %s", VarOptionsFileMp3[ Cpt ] );
+			Debit = gtk_menu_item_new_with_mnemonic( Str );
+			g_free( Str );
+			Str = NULL;
+			gtk_widget_show( Debit );
+			gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+			g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_mp3_activate), GINT_TO_POINTER(Cpt));
+		}
+	
+	// VBR-NEW
+	Type = gtk_menu_item_new_with_mnemonic( "Vbr New" );
+	gtk_widget_show( Type );
+	gtk_container_add( GTK_CONTAINER( Menu), Type );
+		
+		// SUBMENU VBR-NEW
+		SubMenu = gtk_menu_new();
+		gtk_menu_item_set_submenu( GTK_MENU_ITEM(Type), SubMenu );
+		for( Cpt = 44; Cpt <= 59; Cpt ++ ) {
+			if( p_debit == Cpt )
+				Str = g_strdup_printf( ">%s", VarOptionsFileMp3[ Cpt ] );
+			else	Str = g_strdup_printf( "  %s", VarOptionsFileMp3[ Cpt ] );
+			Debit = gtk_menu_item_new_with_mnemonic( Str );
+			g_free( Str );
+			Str = NULL;
+			gtk_widget_show( Debit );
+			gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+			g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_mp3_activate), GINT_TO_POINTER(Cpt));
+		}
+	
+	// MODE
+	Type = gtk_menu_item_new_with_mnemonic( "Mode" );
+	gtk_widget_show( Type );
+	gtk_container_add( GTK_CONTAINER( Menu), Type );
+		
+		// SUBMENU MODE
+		SubMenu = gtk_menu_new();
+		gtk_menu_item_set_submenu( GTK_MENU_ITEM(Type), SubMenu );
+		for( Cpt = 60; Cpt <= 65; Cpt ++ ) {
+			if( p_mode == Cpt )
+				Str = g_strdup_printf( "> %s", VarOptionsFileMp3[ Cpt ] );
+			else	Str = g_strdup_printf( "  %s", VarOptionsFileMp3[ Cpt ] );
+			Debit = gtk_menu_item_new_with_mnemonic( Str );
+			g_free( Str );
+			Str = NULL;
+			gtk_widget_show( Debit );
+			gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+			g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_mp3_activate), GINT_TO_POINTER(Cpt));
+		}
+		
+	// REMOVE ENTRY
+	if( p_debit > -1 ) {
+		Separate = gtk_separator_menu_item_new(  );
+		gtk_widget_show( Separate );
+		gtk_container_add( GTK_CONTAINER( Menu), Separate );
+		Separate = gtk_menu_item_new_with_mnemonic( "Effacer la saisie" );
+		gtk_widget_show( Separate );
+		gtk_container_add( GTK_CONTAINER(Menu), Separate );	
+		g_signal_connect( (gpointer)Separate, "activate", G_CALLBACK(on_type_file_mp3_activate), GINT_TO_POINTER(-1));
+	}
+	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu, "Menu" );
+	
+	gtk_menu_popup( GTK_MENU(Menu), NULL, NULL, NULL, NULL, 3, 0 );
+}
+
+
+
+// 
+// POPUP OGG FILES
+// 
+/*
+DEBIT:		45  kbit/s / 64  kbit/s / 80  kbit/s / 96  kbit/s / 112  kbit/s / 128  kbit/s / 160  kbit/s / 192  kbit/s / 224  kbit/s / 256  kbit/s / 320  kbit/s / 
+		Qualite -1 -Moins bonne qualite / Qualite  0 / Qualite  1 / Qualite  2 / Qualite  3 -Defaut / Qualite  4 / Qualite  5 / Qualite  6 / Qualite  7 / Qualite  8 / Qualite  9 / Qualite  10 -Meilleure qualite
+MANAGED:	Oui / Non
+DOWNMIX:	Mono force / Stereo
+*/
+gchar *VarOptionsFileOgg[] = {
+	// 0 .. 22
+	" 45  kbit/s", " 64  kbit/s", " 80  kbit/s", " 96  kbit/s", "112  kbit/s", "128  kbit/s", "160  kbit/", "192  kbit/s", "224  kbit/s", "256  kbit/s", "320  kbit/s",
+	gettext_noop("Qualite -1 [ Moins bonne qualite ]"), gettext_noop("Qualite  0"), gettext_noop("Qualite  1"), gettext_noop("Qualite  2"),
+	gettext_noop("Qualite  3 [ Defaut ]"), gettext_noop("Qualite  4"), gettext_noop("Qualite  5"), gettext_noop("Qualite  6"), gettext_noop("Qualite  7"),
+	gettext_noop("Qualite  8"), gettext_noop("Qualite  9"), gettext_noop("Qualite  10 [ Meilleure qualite ]"),
+	// 23 .. 24
+	gettext_noop("Oui"), gettext_noop("Non"),
+	// 25 .. 26
+	"Mono force", "Stereo"
+};
+
+// 
+// 
+void on_type_file_ogg_activate( GtkMenuItem *menuitem, gpointer user_data )
+{
+	gint	Choice = GPOINTER_TO_INT(user_data);
+	
+	if( -1 == Choice ) {
+		// g_print( "REMOVE\n");
+		Detail_VarOptionsFileOggMp3->Ogg_Debit   = -1;	// SET DEBIT
+		Detail_VarOptionsFileOggMp3->Ogg_Managed = -1;	// SET MANAGED
+		Detail_VarOptionsFileOggMp3->Ogg_Downmix = -1;	// SET DOWNMIX
+		FileMp3Ogg_update_newbitrate( FILE_IS_OGG );
+		return;
+	}
+	
+	// OGG: DEBIT MANAGED DOWNMIX
+	if( Choice <= 22 )
+		Detail_VarOptionsFileOggMp3->Ogg_Debit = Choice;	// SET DEBIT
+	else if( Choice <= 24)
+		Detail_VarOptionsFileOggMp3->Ogg_Managed = Choice;	// SET MANAGED
+	else
+		Detail_VarOptionsFileOggMp3->Ogg_Downmix = Choice;	// SET DOWNMIX
+	
+	// SELECTIONS DES DEUX OPTIONS OBLIGATOIRE
+	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Debit )	Detail_VarOptionsFileOggMp3->Ogg_Debit   = 0;
+	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Managed )	Detail_VarOptionsFileOggMp3->Ogg_Managed = 23;
+	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Downmix )	Detail_VarOptionsFileOggMp3->Ogg_Downmix = 25;
+	
+	if( Detail_VarOptionsFileOggMp3->Ogg_Debit >= 11 )	Detail_VarOptionsFileOggMp3->Ogg_Managed = -1;
+	if( Detail_VarOptionsFileOggMp3->Ogg_Debit >= 9 )	Detail_VarOptionsFileOggMp3->Ogg_Downmix = -1;
+	
+	Detail_VarOptionsFileOggMp3->BoolChanged = ( -1 != Detail_VarOptionsFileOggMp3->Ogg_Debit || -1 != Detail_VarOptionsFileOggMp3->Ogg_Managed || -1 != Detail_VarOptionsFileOggMp3->Ogg_Downmix );
+	
+	FileMp3Ogg_update_newbitrate( FILE_IS_OGG );
+}
+// 
+// 
+void popup_file_ogg_type( DETAIL *detail, gint p_debit, gint p_managed, gint p_downmix )
+{
+	GtkWidget	*Menu;
+	GtkWidget	*Debit;
+	GtkWidget	*SubMenu;
+	GtkWidget	*Separate;
+	gint		Cpt;
+	gchar		*Str = NULL;
+	
+	Detail_VarOptionsFileOggMp3 = detail;
+	
+	Menu = gtk_menu_new(  );
+	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	// DEBIT
+	Debit = gtk_menu_item_new_with_mnemonic( "Debit" );
+	gtk_widget_show( Debit );
+	gtk_container_add( GTK_CONTAINER( Menu), Debit );
+		
+		// SUBMENU DEBIT
+		SubMenu = gtk_menu_new();
+		gtk_menu_item_set_submenu( GTK_MENU_ITEM(Debit), SubMenu );
+		for( Cpt = 0; Cpt <= 22; Cpt ++ ) {
+			if( p_debit == Cpt )
+				Str = g_strdup_printf( ">%s", VarOptionsFileOgg[ Cpt ] );
+			else	Str = g_strdup_printf( "  %s", VarOptionsFileOgg[ Cpt ] );
+			Debit = gtk_menu_item_new_with_mnemonic( Str );
+			g_free( Str );
+			Str = NULL;
+			gtk_widget_show( Debit );
+			gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+			g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_ogg_activate), GINT_TO_POINTER(Cpt));
+		}
+	
+	// MANAGED
+	if( p_debit < 11 ) {
+		Debit = gtk_menu_item_new_with_mnemonic( "Managed" );
+		gtk_widget_show( Debit );
+		gtk_container_add( GTK_CONTAINER( Menu), Debit );
+		
+			// SUBMENU MANAGED
+			SubMenu = gtk_menu_new();
+			gtk_menu_item_set_submenu( GTK_MENU_ITEM(Debit), SubMenu );
+			for( Cpt = 23; Cpt <= 24; Cpt ++ ) {
+				if( p_managed == Cpt )
+					Str = g_strdup_printf( ">%s", VarOptionsFileOgg[ Cpt ] );
+				else	Str = g_strdup_printf( "  %s", VarOptionsFileOgg[ Cpt ] );
+				Debit = gtk_menu_item_new_with_mnemonic( Str );
+				g_free( Str );
+				Str = NULL;
+				gtk_widget_show( Debit );
+				gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+				g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_ogg_activate), GINT_TO_POINTER(Cpt));
+			}
+	}
+	
+	// DOWNMIX
+	if( p_debit < 9 ) {
+		Debit = gtk_menu_item_new_with_mnemonic( "Downmix" );
+		gtk_widget_show( Debit );
+		gtk_container_add( GTK_CONTAINER( Menu), Debit );
+		
+			// SUBMENU DOWNMIX
+			SubMenu = gtk_menu_new();
+			gtk_menu_item_set_submenu( GTK_MENU_ITEM(Debit), SubMenu );
+			for( Cpt = 25; Cpt <= 26; Cpt ++ ) {
+				if( p_downmix == Cpt )
+					Str = g_strdup_printf( ">%s", VarOptionsFileOgg[ Cpt ] );
+				else	Str = g_strdup_printf( "  %s", VarOptionsFileOgg[ Cpt ] );
+				Debit = gtk_menu_item_new_with_mnemonic( Str );
+				g_free( Str );
+				Str = NULL;
+				gtk_widget_show( Debit );
+				gtk_container_add( GTK_CONTAINER(SubMenu), Debit  );
+				g_signal_connect( (gpointer)Debit, "activate", G_CALLBACK(on_type_file_ogg_activate), GINT_TO_POINTER(Cpt));
+			}
+	}
+	
+	// REMOVE ENTRY
+	if( p_debit > -1 ) {
+		Separate = gtk_separator_menu_item_new(  );
+		gtk_widget_show( Separate );
+		gtk_container_add( GTK_CONTAINER( Menu), Separate );
+		Separate = gtk_menu_item_new_with_mnemonic( "Effacer la saisie" );
+		gtk_widget_show( Separate );
+		gtk_container_add( GTK_CONTAINER(Menu), Separate );	
+		g_signal_connect( (gpointer)Separate, "activate", G_CALLBACK(on_type_file_ogg_activate), GINT_TO_POINTER(-1));
+	}
+	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu, "Menu" );
+	
+	gtk_menu_popup( GTK_MENU(Menu), NULL, NULL, NULL, NULL, 3, 0 );
+}
+// 
+// 
+gchar *popup_get_param_ogg( gint p_debit, gint p_managed, gint p_downmix )
+{
+	gchar *val_bitrate_ogg[] = {
+		"--bitrate=45",
+		"--bitrate=64",
+		"--bitrate=80",
+		"--bitrate=96",
+		"--bitrate=112",
+		"--bitrate=128",
+		"--bitrate=160",
+		"--bitrate=192",
+		"--bitrate=224",
+		"--bitrate=256",
+		"--bitrate=320",
+		"--quality=-1",
+		"--quality=0",
+		"--quality=1",
+		"--quality=2",
+		"--quality=3",
+		"--quality=4",
+		"--quality=5",
+		"--quality=6",
+		"--quality=7",
+		"--quality=8",
+		"--quality=9",
+		"--quality=10"
+		};
+	gchar	*StrRet = NULL;
+	
+	if( p_debit > -1 ) {
+		StrRet = g_strdup_printf( "%s%s%s",
+				val_bitrate_ogg[ p_debit ], 
+				( p_debit < 11 && p_managed == 23 ) ? " --managed" : "",
+				( p_debit < 9 && p_downmix == 25 ) ? " --downmix" : ""
+				);
+	}
+	return( (gchar *)StrRet );
+}
+// 
+// 
+gchar *popup_get_param_mp3( gint p_debit, gint p_mode )
+{
+	static 	gchar *str_param_mp3 [] = {
+		// ABR
+		// 0 .. 13
+		"-b 32",
+		"-b 40",
+		"-b 48",
+		"-b 56",
+		"-b 64",
+		"-b 80",
+		"-b 96",
+		"-b 112",
+		"-b 128",
+		"-b 160",
+		"-b 192",
+		"-b 224",
+		"-b 256",
+		"-b 320",
+		// CBR
+		// 14 .. 28
+		"-b 32",
+		"-b 40",
+		"-b 48",
+		"-b 56",
+		"-b 64",
+		"-b 80",
+		"-b 96",
+		"-b 112",
+		"-b 128",
+		"-b 160",
+		"-b 192",
+		"-b 224",
+		"-b 256",
+		"-b 320",
+		"--preset insane",
+		// VBR
+		// 29 .. 43
+		"--preset medium",
+		"--preset standard",
+		"--preset extreme",
+		"--preset fast standard",
+		"--preset fast extreme",
+		"-V0",
+		"-V1",
+		"-V2",
+		"-V3",
+		"-V4",
+		"-V5",
+		"-V6",
+		"-V7",
+		"-V8",
+		"-V9",
+		// VBR-NEW
+		// 44 .. 59
+		"--vbr-new",
+		"--vbr-new --preset medium",
+		"--vbr-new --preset standard",
+		"--vbr-new --preset extreme",
+		"--vbr-new --preset fast standard",
+		"--vbr-new --preset fast extreme",
+		"--vbr-new -V0",
+		"--vbr-new -V1",
+		"--vbr-new -V2",
+		"--vbr-new -V3",
+		"--vbr-new -V4",
+		"--vbr-new -V5",
+		"--vbr-new -V6",
+		"--vbr-new -V7",
+		"--vbr-new -V8",
+		"--vbr-new -V9",
+		// MODE
+		// 60 .. 65
+		"",		// Defaut
+		"-m s",		// Stereo
+		"-m j",		// Join Stereo
+		"-m f",		// Forced Join Stereo
+		"-m d",		// Duo Channels
+		"-m m"		// Mono
+		};
+	gchar	*StrRet = NULL;
+	
+	if( p_debit > -1) {
+		StrRet = g_strdup_printf( "%s%s%s",
+				str_param_mp3[ p_debit ],
+				( p_mode == 60 ) ? "" : " ",
+				( p_mode > 60 ) ? str_param_mp3[ p_mode ] : ""
+				);
+	}
+	return( (gchar *)StrRet );
+}
+
+
+
+
 
 
 
