@@ -59,6 +59,11 @@ extern CD_POPUP_GENRE CdPopupGenre ;
 void	popup_menu_cd( void );
 
 
+void	popup_file_mp3_type( DETAIL *detail, gint p_debit, gint p_mode );
+void	popup_file_ogg_type( DETAIL *detail, gint p_debit, gint p_managed, gint p_downmix );
+gchar	*popup_get_param_ogg( gint p_debit, gint p_managed, gint p_downmix );
+gchar	*popup_get_param_mp3( gint p_debit, gint p_mode );
+
 #endif
 
 
