@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 
@@ -146,11 +141,10 @@ GList *proc_get_proc_init_cdrominfo (void)
 				ps = s_proc;
 				while ((*ps >= 'a' && *ps <= 'z') || (*ps >= '0' && *ps <= '9')) ps++;
 				*ps = '\0';
-				/*g_print ("1>%s\n", s_proc);*/
+				// g_print ("1>%s\n", s_proc);
 
 				s_alloc = g_strdup (s_proc);
 				List = g_list_append (List, s_alloc);
-
 				while (*p && ((*p >= 'a' && *p <= 'z') || (*p >= '0' && *p <= '9'))) p++;
 
 			}
