@@ -29,15 +29,10 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
 #include <gtk/gtk.h>
 #include <pthread.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-
 #include <stdlib.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -49,6 +44,7 @@
 
 #include "global.h"
 #include "file.h"
+#include "bacon.h"
 #include "process.h"
 
 
@@ -57,19 +53,29 @@ typedef struct {
 	guint	handler_timeout;
 	size_t	Size_XCFA_FILE_LOAD;
 	GSList	*gslist;
-	// GSList	*gslist_remove;
 	FILE	*fp;
+	GList	*GslistBacon;
 } VAR_PROCESS;
 
 VAR_PROCESS VarProcess = {
 			0,
 			-1,
 			NULL,
+			NULL,
 			NULL
 			};
 
+extern BaconMessageConnection *connection;
 
 
+// 
+// 
+// VarProcess.GslistBacon = libutils_remove_glist( VarProcess.GslistBacon )
+// 
+void process_set_list_bacon( gchar *p_Name )
+{
+	VarProcess.GslistBacon = g_list_append( VarProcess.GslistBacon, g_strdup( p_Name ));
+}
 // 
 // 
 void process_debug (gchar *p_trace)
@@ -116,6 +122,9 @@ static gint process_level_timeout_do (gpointer data)
 	// FIN DU TIMEOUT
 	gtk_timeout_remove (VarProcess.handler_timeout);
 	
+	// 
+	bacon_message_connection_free( connection );
+		
 #undef PROCESS_MAX_CARS
 	return (TRUE);
 }
@@ -129,12 +138,9 @@ void process_goto_timeout (void)
 		g_usleep (20);
 		VarProcess.handler_timeout = gtk_timeout_add (400, process_level_timeout_do, 0);
 	}
-}
-// 
-// 
-gboolean process_exist_file (void)
-{
-	return (libutils_test_file_exist (XCFA_FILE_LOAD));
+	else {
+		bacon_message_connection_free( connection );
+	}
 }
 
 
