@@ -31,7 +31,7 @@
 #define XCFA_FILE_LOAD		"/tmp/xcfa_file_load.txt"
 
 void		process_goto_timeout (void);
-gboolean	process_exist_file (void);
+void		process_set_list_bacon( gchar *p_Name );
 
 #endif
 
