@@ -28,11 +28,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -85,11 +80,12 @@ typedef struct {
 	gboolean  tst;
 } Tsearchdrive;
 
-/* definition de tous les type de bus
-*/
+// definition de tous les type de bus
+// 
 Tsearchdrive listesearchdrives[] = {
-	/* 10 - LINUX_IDE : pure ide devices with linux
-	*/
+	/* 
+	 *  10 - LINUX_IDE : pure ide devices with linux
+	 */
 	{ IDE, "dev=/dev/hda",   "/dev/hda",  "hda", FALSE },
 	{ IDE, "dev=/dev/hdb",   "/dev/hdb",  "hdb", FALSE },
 	{ IDE, "dev=/dev/hdc",   "/dev/hdc",  "hdc", FALSE },
@@ -100,8 +96,9 @@ Tsearchdrive listesearchdrives[] = {
 	{ IDE, "dev=/dev/hdh",   "/dev/hdh",  "hdh", FALSE },
 	{ IDE, "dev=/dev/hdi",   "/dev/hdi",  "hdi", FALSE },
 	{ IDE, "dev=/dev/hdj",   "/dev/hdj",  "hdj", FALSE },
-	/* 28 - LINUX_SCSI : SCSI alias with linux
-	*/
+	/* 
+	 *  28 - LINUX_SCSI : SCSI alias with linux
+	 */
 	{ SCSI, "dev=/dev/scd0", "/dev/scd0", "scd0", FALSE },
 	{ SCSI, "dev=/dev/scd1", "/dev/scd1", "scd1", FALSE },
 	{ SCSI, "dev=/dev/scd2", "/dev/scd2", "scd2", FALSE },
@@ -130,8 +127,9 @@ Tsearchdrive listesearchdrives[] = {
 	{ SCSI, "dev=/dev/sge",  "/dev/sge",  "sge", FALSE },
 	{ SCSI, "dev=/dev/sgf",  "/dev/sgf",  "sgf", FALSE },
 	{ SCSI, "dev=/dev/sgg",  "/dev/sgg",  "sgg", FALSE },
-	/* The end of list
-	*/
+	/* 
+	 *  The end of list
+	 */
 	{ _NONE_, NULL, NULL, NULL, FALSE}
 };
 
@@ -257,6 +255,7 @@ GList *scan_scan_drives_cd_dvd (void)
 	/* test is 'dvd+rw-tools package' present ? */
 	if (libutils_find_file ("dvd+rw-mediainfo") == FALSE) {
 		wininfo_create (
+			WindMain,
 			_("PACKAGE dvd+rw-tools ABSENT"),
 			_("Le package 'dvd+rw-tools' est absent"),
 			  "\n",
@@ -311,87 +310,91 @@ GList *scan_scan_drives_cd_dvd (void)
 		g_print ("\nAnalyse devices in : ");
 		g_print ("%s::%s(line=%d) \n", __FILE__, __FUNCTION__, __LINE__);
 	}
-	for (pass = 0, Lcurentry = listesearchdrives; Lcurentry->detectline; pass++, Lcurentry++) {
+	
+	if( TRUE == libutils_test_dir_exist( "/dev" )) {
+		for (pass = 0, Lcurentry = listesearchdrives; Lcurentry->detectline; pass++, Lcurentry++) {
 
-		/* Entree en test ? */
-		if (Lcurentry->tst == FALSE) continue;
+			/* Entree en test ? */
+			if (Lcurentry->tst == FALSE) continue;
+			
+			if( FALSE == libutils_access_mode( Lcurentry->useline )) continue;
+			
+			/* TODO
+			*  TODO : 'dvd+rw-mediainfo' FONCTIONNE T-IL AUSSI AVEC LES LECTEURS DE CD ?
+			*  TODO : IL FAUDRAIT AUSSI FAIRE UN TEST AVEC DES LECTEURS / GRAVEURS DE CD
+			*  TODO
+			*/		
+			gstr = GetInfo_mediainfo( Lcurentry->useline );
+			Lout = gstr->str;
 
-/* TODO
-*  TODO : 'dvd+rw-mediainfo' FONCTIONNE T-IL AUSSI AVEC LES LECTEURS DE CD ?
-*  TODO : IL FAUDRAIT AUSSI FAIRE UN TEST AVEC DES LECTEURS / GRAVEURS DE CD
-*  TODO
-*/
-		gstr = GetInfo_mediainfo (Lcurentry->useline);
-		Lout = gstr->str;
+			if (*Lout) {
+				if ((Ptr = strstr (Lout, "INQUIRY:"))) {
+					/* sur mon ordi :
+					INQUIRY:                [_NEC    ][DVD_RW ND-3520A ][1.04]
+					INQUIRY:                [_NEC    ][DVD_RW ND-3520A ][3.05]  -- Apres un flash bios
+					INQUIRY:                [_NEC    ][DVD_RW ND-3520A ][3.06]  -- Apres un flash bios
+					INQUIRY:                [DVDRW   ][IDE 16X         ][A07R]
+					INQUIRY:                [DVDRW   ][IDE 16X         ][A190]  -- Apres un flash bios
+					*/
+					/* remplacer tous les '[' et les ']' par ' ' */
+					if (strchr (Ptr, '[') && strchr (Ptr, ']')) {
+						Ptr = strchr (Ptr, '[');
+						i = 0;
+						while (*Ptr != '\n') str [ i++ ] = *Ptr++;
+						str [ i ] = '\0';
+						while ((Ptr = strchr (str, '['))) *Ptr = ' ';
+						while ((Ptr = strchr (str, ']'))) *Ptr = ' ';
 
-		if (*Lout) {
-			if ((Ptr = strstr (Lout, "INQUIRY:"))) {
-				/* sur mon ordi :
-				INQUIRY:                [_NEC    ][DVD_RW ND-3520A ][1.04]
-				INQUIRY:                [_NEC    ][DVD_RW ND-3520A ][3.05]  -- Apres un flash bios
-				INQUIRY:                [_NEC    ][DVD_RW ND-3520A ][3.06]  -- Apres un flash bios
-				INQUIRY:                [DVDRW   ][IDE 16X         ][A07R]
-				INQUIRY:                [DVDRW   ][IDE 16X         ][A190]  -- Apres un flash bios
-				*/
+						/* supprimer les espaces de debut */
+						Ptr = str;
+						while (*Ptr == ' ') Ptr ++;
+						strcpy (str, Ptr);
 
-				/* remplacer tous les '[' et les ']' par ' ' */
-				if (strchr (Ptr, '[') && strchr (Ptr, ']')) {
-					Ptr = strchr (Ptr, '[');
-					i = 0;
-					while (*Ptr != '\n') str [ i++ ] = *Ptr++;
-					str [ i ] = '\0';
-					while ((Ptr = strchr (str, '['))) *Ptr = ' ';
-					while ((Ptr = strchr (str, ']'))) *Ptr = ' ';
-
-					/* supprimer les espaces de debut */
-					Ptr = str;
-					while (*Ptr == ' ') Ptr ++;
-					strcpy (str, Ptr);
-
-					/* supprimer les espaces de fin */
-					Ptr = str;
-					while (*Ptr) Ptr ++;
-					Ptr --;
-					while (*Ptr == ' ') Ptr --;
-					Ptr ++;
-					*Ptr = '\0';
-
-					/* supprimer les doubles espaces */
-					Ptr = str;
-					while (*Ptr) {
-						if ((*Ptr==' ') && (*(Ptr+1)==' ')) {
-							strcpy (Ptr, Ptr+1);
-							Ptr = str;
-							continue;
-						}
+						/* supprimer les espaces de fin */
+						Ptr = str;
+						while (*Ptr) Ptr ++;
+						Ptr --;
+						while (*Ptr == ' ') Ptr --;
 						Ptr ++;
-					}
-					if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
-						g_print ("\tline[ %d ] %s   ", pass, Lcurentry->tp == IDE ? "IDE" : "SCSI");
-						g_print ("%s\t'%s'\n", Lcurentry->useline, str);
-					}
-					if ((Media = (MEDIA *)g_malloc0 (sizeof (MEDIA)))) {
-						Media->Full_Name = g_strdup (str);
-						Media->Device    = g_strdup (Lcurentry->useline);
-						Media->Num       = var_scancd.TotalReadersDetected;
-						var_scancd.TotalReadersDetected ++;
+						*Ptr = '\0';
+
+						/* supprimer les doubles espaces */
+						Ptr = str;
+						while (*Ptr) {
+							if ((*Ptr==' ') && (*(Ptr+1)==' ')) {
+								strcpy (Ptr, Ptr+1);
+								Ptr = str;
+								continue;
+							}
+							Ptr ++;
+						}
+						if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+							g_print ("\tline[ %d ] %s   ", pass, Lcurentry->tp == IDE ? "IDE" : "SCSI");
+							g_print ("%s\t'%s'\n", Lcurentry->useline, str);
+						}
+						if ((Media = (MEDIA *)g_malloc0 (sizeof (MEDIA)))) {
+							Media->Full_Name = g_strdup (str);
+							Media->Device    = g_strdup (Lcurentry->useline);
+							Media->Num       = var_scancd.TotalReadersDetected;
+							var_scancd.TotalReadersDetected ++;
 						
-						Media->line      =  pass;
-						Media->type      = Lcurentry->tp == IDE ? 0 : 1;
+							Media->line      =  pass;
+							Media->type      = Lcurentry->tp == IDE ? 0 : 1;
 						
-						List = g_list_append (List, Media);
+							List = g_list_append (List, Media);
+						}
+					}
+					else {
+						PRINT_FUNC_LF();
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("La ligne renvoyee par: dvd+rw-mediainfo est inconnue\n");
 					}
-				}
-				else {
-					PRINT_FUNC_LF();
-					if( TRUE == OptionsCommandLine.BoolVerboseMode )
-						g_print ("La ligne renvoyee par: dvd+rw-mediainfo est inconnue\n");
 				}
 			}
-		}
 
-		g_string_free (gstr, TRUE);
-		Lout = NULL;
+			g_string_free (gstr, TRUE);
+			Lout = NULL;
+		}
 	}
 	g_print ("\n");
 
