@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <stdio.h>
@@ -80,12 +75,12 @@ void SetAjust (void);
 void split_set_time (void)
 {
 	gint		sec;
-	gdouble		dsec;
+	// gdouble		dsec;
 	gdouble		TimeSongSec;
 	gdouble		Percent;
-	gint		H, M, S, C;
+	gint		H, M, S;
+	// gint		C, hundr;
 	gchar		*Str = NULL;
-	gint		hundr;
 
 	if (NULL == VarSplit.Tags || VarSplit.NbrSelecteurs <= 0) {
 		gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_begin_time_split")), TRUE);
@@ -115,12 +110,12 @@ void split_set_time (void)
 	// POSITION INDEX DEBUT
 	Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-	dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-	hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+	// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+	// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 	H = (sec / 60) / 60;
 	M = (sec / 60) % 60;
 	S = sec % 60;
-	C = hundr;
+	// C = hundr;
 	Str = g_strdup_printf (" <b>%02d:%02d:%02d</b> ", H, M, S);
 	gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_begin_time_split")), TRUE);
 	gtk_label_set_markup (GTK_LABEL(GLADE_GET_OBJECT("label_begin_time_split")), Str);
@@ -129,12 +124,12 @@ void split_set_time (void)
 	// POSITION INDEX FIN
 	Percent = SplitSelector_get_percent_end (VarSplit.SelecteurActif);
 	sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-	dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-	hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+	// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+	// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 	H = (sec / 60) / 60;
 	M = (sec / 60) % 60;
 	S = sec % 60;
-	C = hundr;
+	// C = hundr;
 	Str = g_strdup_printf (" <b>%02d:%02d:%02d</b> ", H, M, S);
 	gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_end_time_split")), TRUE);
 	gtk_label_set_markup (GTK_LABEL(GLADE_GET_OBJECT("label_end_time_split")), Str);
@@ -149,12 +144,12 @@ void split_set_time (void)
 	// DUREE DE LA PLAGE
 	Percent  = SplitSelector_get_percent_end (VarSplit.SelecteurActif) - SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-	dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-	hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+	// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+	// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 	H = (sec / 60) / 60;
 	M = (sec / 60) % 60;
 	S = sec % 60;
-	C = hundr;
+	// C = hundr;
 	Str = g_strdup_printf (" <b>%02d:%02d:%02d</b> ", H, M, S);
 	gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_time_split")), TRUE);
 	gtk_label_set_markup (GTK_LABEL(GLADE_GET_OBJECT("label_time_split")), Str);
@@ -163,12 +158,12 @@ void split_set_time (void)
 	// TEMPS DU PLAY
 	Percent = VarSplit.PercentActivePlay;
 	sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-	dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-	hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+	// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+	// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 	H = (sec / 60) / 60;
 	M = (sec / 60) % 60;
 	S = sec % 60;
-	C = hundr;
+	// C = hundr;
 	Str = g_strdup_printf (" <b>%02d:%02d:%02d</b> ", H, M, S);
 	gtk_label_set_use_markup (GTK_LABEL(GLADE_GET_OBJECT("label_curseur_lecture_split")), TRUE);
 	gtk_label_set_markup (GTK_LABEL(GLADE_GET_OBJECT("label_curseur_lecture_split")), Str);
@@ -357,6 +352,7 @@ void split_file_load (gchar *p_PathNameFile)
 
 	if (0 == strcmp (p_PathNameFile, SPLIT_FILE_TMP_WAV)) {
 		wininfo_create (
+			WindMain,
 			_("Ce fichier appartient a XCFA"),
 			_("Selectionnez un autre fichier."),
 			  "");
@@ -365,6 +361,7 @@ void split_file_load (gchar *p_PathNameFile)
 	
 	if (libutils_get_size_file (p_PathNameFile) <= 0) {
 		wininfo_create (
+			WindMain,
 			_("Fichier vide"),
 			_("Le fichier ne contient aucune donnee !!!"),
 			  "");
@@ -384,6 +381,7 @@ void split_file_load (gchar *p_PathNameFile)
 		}
 		if (0 == strcmp (PathNameFile, SPLIT_FILE_TMP_WAV)) {
 			wininfo_create (
+				WindMain,
 				_("Ce fichier appartient a XCFA"),
 				_("Selectionnez un autre fichier."),
 				  "");
@@ -409,6 +407,7 @@ void split_file_load (gchar *p_PathNameFile)
 		if (FALSE == PrgInit.bool_sox || FALSE == PrgInit.bool_mplayer) {
 		
 			wininfo_create (
+				WindMain,
 				_("Sox et Mplayer absents"),
 				_("Sox et Mplayer sont absents de votre"),
 			  	"\n",
@@ -464,6 +463,7 @@ void split_file_load_continue (gchar *p_PathNameFile)
 	}
 	else {
 		wininfo_create (
+			WindMain,
 			_("Erreur de choix de fichier"),
 			_("Veuillez selectionner un fichier de type WAV FLAC MP3 OGG APE"),
 			  "");
@@ -501,6 +501,7 @@ void split_maj_file_load (gchar *path)
 	
 	if (FALSE == BoolTypeFileIsOk) {
 		wininfo_create (
+			WindMain,
 			_("Mauvais type de fichier"),
 			_("Les types de fichiers acceptes\nsont: WAV FLAC MP3 OGG APE WMA CUE"),
 			  "");
@@ -574,6 +575,7 @@ void split_load_from_dnd (GSList *p_list)
 	
 	if (FALSE == BoolTypeFileIsOk) {
 		wininfo_create (
+			WindMain,
 			_("Mauvais type de fichier"),
 			_("Les types de fichiers acceptes\nsont: WAV FLAC MP3 OGG APE WMA CUE"),
 			  "");
@@ -683,7 +685,7 @@ void split_play (void)
 // 
 void on_button_play_begin_split_clicked (GtkButton *button, gpointer user_data)
 {
-	gdouble		Percent;
+	// gdouble		Percent;
 	
 	// PRINT_FUNC_LF();
 	
@@ -691,7 +693,8 @@ void on_button_play_begin_split_clicked (GtkButton *button, gpointer user_data)
 	gdouble	PercentEnd   = SplitSelector_get_percent_begin (VarSplit.SelecteurActif) + SplitSelector_get_percent_for_x_secondes (5);
 	
 	VarSplit.BoolPlay = TRUE;
-	Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
+	// Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
+	SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	AlsaPlay_song (
 		VarSplit.PathNameFile,
 		PercentBegin,
@@ -713,7 +716,7 @@ void on_button_play_begin_split_clicked (GtkButton *button, gpointer user_data)
 // 
 void on_button_play_end_split_clicked (GtkButton *button, gpointer user_data)
 {
-	gdouble		Percent;
+	// gdouble		Percent;
 	
 	// PRINT_FUNC_LF();
 	
@@ -721,7 +724,8 @@ void on_button_play_end_split_clicked (GtkButton *button, gpointer user_data)
 	gdouble	PercentEnd   = SplitSelector_get_percent_end (VarSplit.SelecteurActif);
 	
 	VarSplit.BoolPlay = TRUE;
-	Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
+	// Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
+	SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	AlsaPlay_song (
 		VarSplit.PathNameFile,
 		PercentBegin,
