@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -299,6 +299,12 @@ gchar		*SplitCue_read_cue_file (gchar *p_pathname);
 // ---------------------------------------------------------------------------
 // 
 void		SplitConv_to (gchar *p_PathNameFile);
+// 
+// ---------------------------------------------------------------------------
+//  SPLIT_WAV.C
+// ---------------------------------------------------------------------------
+// 
+void		SplitWav_extract( void );
 
 
 #endif
