@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -309,6 +304,7 @@ static gint SplitConv_timeout (gpointer data)
 				WindScan_close ();
 				if( FALSE == WindScan_close_request()) {
 					wininfo_create (
+						WindMain,
 						_("Erreur SOX"),
 						_("Le programme SOX de votre distribution"),
 						"\n",
@@ -325,6 +321,7 @@ static gint SplitConv_timeout (gpointer data)
 				WindScan_close ();
 				if( FALSE == WindScan_close_request()) {
 					wininfo_create (
+						WindMain,
 						_("Erreur SOX"),
 						_("Le programme SOX de votre distribution"),
 						"\n",
