@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 
@@ -492,12 +487,11 @@ gint SplitSelector_get_4_secondes_to_int (void)
 {	
 	gint		Cpt;
 	gint		sec;
-	gdouble		dsec;
+	// gdouble		dsec;
 	gdouble		TimeSongSec;
 	gdouble		Percent = 0.0;
-	gint		H, M, S, C;
-	// gchar		*Str = NULL;
-	gint		hundr;
+	gint		H, M, S;
+	// gint		hundr, C;
 	gint		Len = -1;
 	
 	if (NULL == VarSplit.Tags || VarSplit.NbrSelecteurs <= 0) {
@@ -512,12 +506,12 @@ gint SplitSelector_get_4_secondes_to_int (void)
 	for (Cpt = 0; ; Cpt ++) {
 		
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+		// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+		// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 		H = (sec / 60) / 60;
 		M = (sec / 60) % 60;
 		S = sec % 60;
-		C = hundr;
+		// C = hundr;
 		if (H == 0 && M == 0 && S == 5) {
 			Len = (gint)(((gdouble)SplitSpectre_get_with()  * Percent) / 100.0);
 			break;
@@ -534,11 +528,11 @@ gdouble SplitSelector_get_percent_for_x_secondes (gint p_secondes)
 {	
 	gint		Cpt;
 	gint		sec;
-	gdouble		dsec;
+	// gdouble		dsec;
 	gdouble		TimeSongSec;
 	gdouble		Percent = 0.0;
-	gint		H, M, S, C;
-	gint		hundr;
+	gint		H, M, S;
+	// gint		hundr, C;
 	
 	if (NULL == VarSplit.Tags || VarSplit.NbrSelecteurs <= 0) {
 		return (-1);
@@ -552,12 +546,12 @@ gdouble SplitSelector_get_percent_for_x_secondes (gint p_secondes)
 	for (Cpt = 0; ; Cpt ++) {
 		
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+		// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+		// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 		H = (sec / 60) / 60;
 		M = (sec / 60) % 60;
 		S = sec % 60;
-		C = hundr;
+		// C = hundr;
 		if (H == 0 && M == 0 && S == p_secondes) {
 			return (Percent);
 		}
