@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <math.h>
 #ifdef ENABLE_STATIC_LIBRARY
@@ -86,12 +81,13 @@ void SplitSpectre_draw_chrono ( GtkWidget *widget )
 	gint			ChronoX;
 	
 	gint			sec;
-	gdouble			dsec;
+	// gdouble			dsec;
 	gdouble			TimeSongSec;
 	gdouble			Percent;
-	gint			H, M, S, C;
+	gint			H, M, S;
 	gchar			*Str = NULL;
-	gint			hundr;
+	// gint			hundr;
+	// gint			C;
 	
 	/*
 	cairo_t		*cr;
@@ -202,12 +198,12 @@ void SplitSpectre_draw_chrono ( GtkWidget *widget )
 		}
 		Percent = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
+		// dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
+		// hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
 		H = (sec / 60) / 60;
 		M = (sec / 60) % 60;
 		S = sec % 60;
-		C = hundr;
+		// C = hundr;
 		Str = g_strdup_printf ("%02d:%02d:%02d", H, M, S);
 
 		pango_layout_set_markup (layout, Str, -1);
@@ -530,6 +526,9 @@ void SplitSpectre_remove (void)
 // 	C'est peut être une option (un bouton) à cogiter pour une future mouture,
 // 	non ? M'est avis qu'not' Christophe serait pas contre...					
 // 
+// PS:
+// 	Et chose fut faite: MERCI Xavier  :-)
+// 
 void SplitSpectre_search_blank_pass (void)
 {
 	gint		IndicePoints = -1;
@@ -818,7 +817,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 					}
 					VarSplit.Tab [ points ].Min = min;
 					VarSplit.Tab [ points ].Max = max;
-
+					
 					points ++;
 				}
 				break;
