@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright :( C) 2003 - 2011 by Claude Bulin
+ *  copyright :( C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -78,8 +78,9 @@ INFO_WAV	*tagswav_get_info( gchar *namefile );
 gboolean	tagswav_file_is_mono( gchar *namefile );
 gboolean	tagswav_file_GetBitrate( gchar *namefile, gint *Channels, gint *Hertz, gint *Bits );
 gint		tagswav_get_time_sec( gchar *namefile );
-gboolean	tagswav_read_file( gchar *wave_file, WAVE *son );
-void		tagswav_close_file( WAVE *son );
+gboolean	tagswav_read_file( gchar *wave_file, WAVE *WaveHeader );
+void		tagswav_close_file( WAVE *WaveHeader );
+void		tagswav_print( gchar *p_PathNameFile );
 // 
 // ---------------------------------------------------------------------------
 //  TAGS.C
