@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -114,8 +109,8 @@ void on_button_cancel_windscan_clicked (GtkButton *button, gpointer user_data)
 static gint WindScan_timeout (gpointer data)
 {
 	if (TRUE == VarWindScan.close_request && TRUE == VarWindScan.IsShow) {
-		VarWindScan.close_request = FALSE;
 		VarWindScan.IsShow = FALSE;
+		VarWindScan.close_request = FALSE;
 		gtk_timeout_remove (VarWindScan.HandlerTimeout);
 		gtk_widget_hide (VarWindScan.AdrWin);
 	}
@@ -134,8 +129,7 @@ gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress)
 	
 	VarWindScan.CloseByUser = FALSE;
 	VarWindScan.close_request = FALSE;
-	// PRINT("------------------------------------------------------------");
-	// g_print( "VarWindScan.IsShow = %s\n", VarWindScan.IsShow ? "TRUE" : "FALSE" );
+
 	if (TRUE == VarWindScan.IsShow) {
 		gdk_window_raise (VarWindScan.AdrWin->window);
 	}
@@ -144,10 +138,11 @@ gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress)
 			VarWindScan.AdrWin = GTK_WIDGET (GLADE_GET_OBJECT("WindScan"));
 			gtk_builder_connect_signals (GtkXcfaProjet, NULL);
 		}
-		gtk_window_set_transient_for (GTK_WINDOW(VarWindScan.AdrWin), GTK_WINDOW(WindMain));
 		gtk_window_set_modal (GTK_WINDOW (VarWindScan.AdrWin), TRUE);
 		libutils_set_default_icone_to_win (VarWindScan.AdrWin);
 
+		gtk_window_set_transient_for( GTK_WINDOW(VarWindScan.AdrWin), GTK_WINDOW(WindMain) );
+		
 		gtk_widget_show (VarWindScan.AdrWin);
 		WindScan_hide_expander ();
 	}
